@@ -21,9 +21,6 @@ EXCLUDE = (
     "cmd/gvedit/csettings.h",
     "cmd/gvedit/imageviewer.cpp",
     "cmd/gvedit/imageviewer.h",
-    "cmd/gvedit/main.cpp",
-    "cmd/gvedit/mainwindow.cpp",
-    "cmd/gvedit/mainwindow.h",
     "cmd/gvedit/mdichild.cpp",
     "cmd/gvedit/mdichild.h",
     "cmd/gvedit/ui_settings.h",
@@ -100,7 +97,6 @@ EXCLUDE = (
     "cmd/tools/gml2gv.c",
     "cmd/tools/gml2gv.h",
     "cmd/tools/graph_generator.c",
-    "cmd/tools/graph_generator.h",
     "cmd/tools/graphml2gv.c",
     "cmd/tools/gv2gml.c",
     "cmd/tools/gv2gxl.c",
@@ -126,7 +122,6 @@ EXCLUDE = (
     "lib/ast/chrtoi.c",
     "lib/ast/error.c",
     "lib/ast/error.h",
-    "lib/ast/fmtbuf.c",
     "lib/ast/fmtesc.c",
     "lib/ast/stresc.c",
     "lib/ast/strmatch.c",
@@ -288,11 +283,9 @@ EXCLUDE = (
     "lib/glcomp/glcompimage.c",
     "lib/glcomp/glcompimage.h",
     "lib/glcomp/glcomplabel.c",
-    "lib/glcomp/glcomplabel.h",
     "lib/glcomp/glcompmouse.c",
     "lib/glcomp/glcompmouse.h",
     "lib/glcomp/glcomppanel.c",
-    "lib/glcomp/glcomppanel.h",
     "lib/glcomp/glcompset.c",
     "lib/glcomp/glcompset.h",
     "lib/glcomp/glcomptextpng.c",
@@ -477,7 +470,6 @@ EXCLUDE = (
     "lib/sfdpgen/post_process.h",
     "lib/sfdpgen/sfdp.h",
     "lib/sfdpgen/sfdpinit.c",
-    "lib/sfdpgen/sfdpinternal.h",
     "lib/sfdpgen/sparse_solve.c",
     "lib/sfdpgen/spring_electrical.c",
     "lib/sfdpgen/spring_electrical.h",
@@ -487,7 +479,6 @@ EXCLUDE = (
     "lib/sfio/sfextern.c",
     "lib/sfio/sfhdr.h",
     "lib/sfio/sfio.h",
-    "lib/sfio/sfscanf.c",
     "lib/sfio/sftable.c",
     "lib/sfio/sfprint.c",
     "lib/sfio/sfvscanf.c",
@@ -561,14 +552,12 @@ EXCLUDE = (
     "plugin/core/gvrender_core_fig.c",
     "plugin/core/gvrender_core_json.c",
     "plugin/core/gvrender_core_map.c",
-    "plugin/core/gvrender_core_mp.c",
     "plugin/core/gvrender_core_pic.c",
     "plugin/core/gvrender_core_pov.c",
     "plugin/core/gvrender_core_ps.c",
     "plugin/core/gvrender_core_svg.c",
     "plugin/core/gvrender_core_tk.c",
     "plugin/devil/gvdevice_devil.c",
-    "plugin/devil/gvplugin_devil.c",
     "plugin/dot_layout/gvlayout_dot_layout.c",
     "plugin/dot_layout/gvplugin_dot_layout.c",
     "plugin/gd/gvdevice_gd.c",
@@ -585,13 +574,10 @@ EXCLUDE = (
     "plugin/gdiplus/gvtextlayout_gdiplus.cpp",
     "plugin/gdk/gvdevice_gdk.c",
     "plugin/gdk/gvloadimage_gdk.c",
-    "plugin/gdk/gvplugin_gdk.c",
     "plugin/gs/gvloadimage_gs.c",
-    "plugin/gs/gvplugin_gs.c",
     "plugin/gtk/callbacks.c",
     "plugin/gtk/callbacks.h",
     "plugin/gtk/gvdevice_gtk.c",
-    "plugin/gtk/gvplugin_gtk.c",
     "plugin/gtk/interface.c",
     "plugin/gtk/interface.h",
     "plugin/gtk/support.c",
@@ -604,7 +590,6 @@ EXCLUDE = (
     "plugin/pango/gvrender_pango.c",
     "plugin/pango/gvtextlayout_pango.c",
     "plugin/poppler/gvloadimage_poppler.c",
-    "plugin/poppler/gvplugin_poppler.c",
     "plugin/quartz/GVTextLayout.h",
     "plugin/quartz/gvdevice_quartz.c",
     "plugin/quartz/gvloadimage_quartz.c",
@@ -618,7 +603,6 @@ EXCLUDE = (
     "plugin/webp/gvloadimage_webp.c",
     "plugin/webp/gvplugin_webp.c",
     "plugin/xlib/gvdevice_xlib.c",
-    "plugin/xlib/gvplugin_xlib.c",
     "tclpkg/gdtclft/gdtclft.c",
     "tclpkg/gv/gv_builtins.c",
     "tclpkg/gv/gv_dummy_init.c",
