@@ -19,6 +19,7 @@
 #include <QTemporaryFile>
 #include <QtWidgets>
 #include <cassert>
+#include <cgraph/rdr.h>
 #include <cstdint>
 #include <qfile.h>
 #include <string>
@@ -40,11 +41,6 @@
 extern int errorPipe(char *errMsg);
 
 #define WIDGET(t, f) ((t *)findChild<t *>(#f))
-typedef struct {
-  const char *data;
-  int len;
-  int cur;
-} rdr_t;
 
 #ifndef _WIN32
 /// `readlink`-alike but dynamically allocates
@@ -208,7 +204,7 @@ static std::string find_share(void) {
          "graphviz" + PATH_SEPARATOR + "gvedit";
 }
 
-bool loadAttrs(const QString fileName, QComboBox *cbNameG, QComboBox *cbNameN,
+bool loadAttrs(const QString &fileName, QComboBox *cbNameG, QComboBox *cbNameN,
                QComboBox *cbNameE) {
   QStringList lines;
   QFile file(fileName);
@@ -245,7 +241,7 @@ bool loadAttrs(const QString fileName, QComboBox *cbNameG, QComboBox *cbNameN,
   return false;
 }
 
-QString stripFileExtension(QString fileName) {
+QString stripFileExtension(const QString &fileName) {
   int idx;
   for (idx = fileName.length(); idx >= 0; idx--) {
     if (fileName.mid(idx, 1) == ".")
@@ -270,22 +266,26 @@ CFrmSettings::CFrmSettings() {
   else
     path = QString::fromStdString(find_share());
 
-  connect(WIDGET(QPushButton, pbAdd), SIGNAL(clicked()), this, SLOT(addSlot()));
-  connect(WIDGET(QPushButton, pbNew), SIGNAL(clicked()), this, SLOT(newSlot()));
-  connect(WIDGET(QPushButton, pbOpen), SIGNAL(clicked()), this,
-          SLOT(openSlot()));
-  connect(WIDGET(QPushButton, pbSave), SIGNAL(clicked()), this,
-          SLOT(saveSlot()));
-  connect(WIDGET(QPushButton, btnOK), SIGNAL(clicked()), this, SLOT(okSlot()));
-  connect(WIDGET(QPushButton, btnCancel), SIGNAL(clicked()), this,
-          SLOT(cancelSlot()));
-  connect(WIDGET(QPushButton, pbOut), SIGNAL(clicked()), this,
-          SLOT(outputSlot()));
-  connect(WIDGET(QPushButton, pbHelp), SIGNAL(clicked()), this,
-          SLOT(helpSlot()));
+  connect(WIDGET(QPushButton, pbAdd), &QPushButton::clicked, this,
+          &CFrmSettings::addSlot);
+  connect(WIDGET(QPushButton, pbNew), &QPushButton::clicked, this,
+          &CFrmSettings::newSlot);
+  connect(WIDGET(QPushButton, pbOpen), &QPushButton::clicked, this,
+          &CFrmSettings::openSlot);
+  connect(WIDGET(QPushButton, pbSave), &QPushButton::clicked, this,
+          &CFrmSettings::saveSlot);
+  connect(WIDGET(QPushButton, btnOK), &QPushButton::clicked, this,
+          &CFrmSettings::okSlot);
+  connect(WIDGET(QPushButton, btnCancel), &QPushButton::clicked, this,
+          &CFrmSettings::cancelSlot);
+  connect(WIDGET(QPushButton, pbOut), &QPushButton::clicked, this,
+          &CFrmSettings::outputSlot);
+  connect(WIDGET(QPushButton, pbHelp), &QPushButton::clicked, this,
+          &CFrmSettings::helpSlot);
 
-  connect(WIDGET(QComboBox, cbScope), SIGNAL(currentIndexChanged(int)), this,
-          SLOT(scopeChangedSlot(int)));
+  connect(WIDGET(QComboBox, cbScope),
+          QOverload<int>::of(&QComboBox::currentIndexChanged), this,
+          &CFrmSettings::scopeChangedSlot);
   scopeChangedSlot(0);
 
   if (path != "") {
@@ -459,7 +459,7 @@ static QString buildTempFile() {
   return a;
 }
 
-void CFrmSettings::doPreview(QString fileName) {
+void CFrmSettings::doPreview(const QString &fileName) {
   if (getActiveWindow()->previewFrm != nullptr) {
     getActiveWindow()->parentFrm->mdiArea->removeSubWindow(
         getActiveWindow()->previewFrm->subWindowRef);
