@@ -9,6 +9,7 @@
  *************************************************************************/
 
 #define STANDALONE
+#include <assert.h>
 #include <sparse/SparseMatrix.h>
 #include <sparse/general.h>
 #include <math.h>
@@ -18,6 +19,7 @@
 #include <string.h>
 #include <cgraph/agxbuf.h>
 #include <cgraph/alloc.h>
+#include <cgraph/list.h>
 #include <cgraph/prisize_t.h>
 #include <cgraph/cgraph.h>
 #include "make_map.h"
@@ -244,62 +246,53 @@ static void plot_dot_labels(FILE *f, int n, int dim, double *x, char **labels, f
 
 }
 
-static void dot_polygon(agxbuf *sbuff, int np, double *xp, double *yp,
-                        double line_width, int fill, const char *cstring) {
+DEFINE_LIST(doubles, double)
 
-  if (np > 0){
-    if (fill >= 0){
-      agxbprint(sbuff, " c %" PRISIZE_T " -%s C %" PRISIZE_T " -%s P %d ",
-                strlen(cstring), cstring, strlen(cstring), cstring, np);
+static void dot_polygon(agxbuf *sbuff, doubles_t xp, doubles_t yp,
+                        double line_width, bool fill, const char *cstring) {
+
+  assert(doubles_size(&xp) == doubles_size(&yp));
+  if (!doubles_is_empty(&xp)){
+    if (fill) {
+      agxbprint(sbuff,
+                " c %" PRISIZE_T " -%s C %" PRISIZE_T " -%s P %" PRISIZE_T " ",
+                strlen(cstring), cstring, strlen(cstring), cstring,
+                doubles_size(&xp));
     } else {
       if (line_width > 0){
 	size_t len_swidth = (size_t)snprintf(NULL, 0, "%f", line_width);
 	agxbprint(sbuff, " c %" PRISIZE_T " -%s S %" PRISIZE_T
-	          " -setlinewidth(%f) L %d ", strlen(cstring), cstring,
-	          len_swidth + 14, line_width, np);
+	          " -setlinewidth(%f) L %" PRISIZE_T " ", strlen(cstring), cstring,
+	          len_swidth + 14, line_width, doubles_size(&xp));
       } else {
-	agxbprint(sbuff, " c %" PRISIZE_T " -%s L %d ", strlen(cstring), cstring, np);
+	agxbprint(sbuff, " c %" PRISIZE_T " -%s L %" PRISIZE_T " ", strlen(cstring),
+	          cstring, doubles_size(&xp));
       }
     }
-    for (int i = 0; i < np; i++){
-      agxbprint(sbuff, " %f %f",xp[i], yp[i]);
+    for (size_t i = 0; i < doubles_size(&xp); i++) {
+      agxbprint(sbuff, " %f %f", doubles_get(&xp, i), doubles_get(&yp, i));
     }
   }
 }
 
-static void dot_one_poly(agxbuf *sbuff, double line_width, int fill, int np,
-                         double *xp, double *yp, const char *cstring) {
-  dot_polygon(sbuff, np, xp, yp, line_width, fill, cstring);
-}
-
 static void plot_dot_polygons(agxbuf *sbuff, double line_width,
                               const char *line_color, SparseMatrix polys,
                               double *x_poly, int *polys_groups, float *r,
                               float *g, float *b, const char *opacity) {
   int i, j, *ia = polys->ia, *ja = polys->ja, *a = polys->a, npolys = polys->m, nverts = polys->n, ipoly,first;
-  int np = 0;
-  int fill = -1;
-  int use_line = (line_width >= 0);
+  const bool fill = false;
+  const bool use_line = line_width >= 0;
   
   agxbuf cstring_buffer = {0};
   agxbput(&cstring_buffer, "#aaaaaaff");
   char *cstring = agxbuse(&cstring_buffer);
 
-  size_t maxlen = 0;
-  for (i = 0; i < npolys; i++) {
-    int len = ia[i + 1] - ia[i];
-    if (len > 0 && (size_t)len > maxlen) {
-      maxlen = (size_t)len;
-    }
-  }
-
-  double *xp = gv_calloc(maxlen, sizeof(double));
-  double *yp = gv_calloc(maxlen, sizeof(double));
+  doubles_t xp = {0};
+  doubles_t yp = {0};
 
   if (Verbose) fprintf(stderr,"npolys = %d\n",npolys);
   first = abs(a[0]); ipoly = first + 1;
   for (i = 0; i < npolys; i++){
-    np = 0;
     for (j = ia[i]; j < ia[i+1]; j++){
       assert(ja[j] < nverts && ja[j] >= 0);
       (void)nverts;
@@ -310,21 +303,24 @@ static void plot_dot_polygons(agxbuf *sbuff, double line_width,
 	          &cstring_buffer, opacity);
 	  cstring = agxbuse(&cstring_buffer);
 	}
-	dot_one_poly(sbuff, line_width, fill, np, xp, yp, cstring);
-	np = 0;/* start a new polygon */
+	dot_polygon(sbuff, xp, yp, line_width, fill, cstring);
+	// start a new polygon
+	doubles_clear(&xp);
+	doubles_clear(&yp);
       } 
-      xp[np] = x_poly[2*ja[j]]; yp[np++] = x_poly[2*ja[j]+1];
+      doubles_append(&xp, x_poly[2 * ja[j]]);
+      doubles_append(&yp, x_poly[2 * ja[j] + 1]);
     }
     if (use_line) {
-      dot_one_poly(sbuff, line_width, fill, np, xp, yp, line_color);
+      dot_polygon(sbuff, xp, yp, line_width, fill, line_color);
     } else {
       /* why set fill to polys_groups[i]?*/
-      dot_one_poly(sbuff, -1, 1, np, xp, yp, cstring);
+      dot_polygon(sbuff, xp, yp, -1, true, cstring);
     }
   }
   agxbfree(&cstring_buffer);
-  free(xp);
-  free(yp);
+  doubles_free(&xp);
+  doubles_free(&yp);
 }
 
 void plot_dot_map(Agraph_t* gr, int n, int dim, double *x, SparseMatrix polys,
@@ -497,33 +493,22 @@ static void conn_comp(int n, SparseMatrix A, int *groups, SparseMatrix *poly_poi
 
 }
 
-static void get_poly_lines(int nt, SparseMatrix graph, SparseMatrix E, int ncomps, int *comps_ptr, int *comps,
-			   int *groups, int *mask, SparseMatrix *poly_lines, int **polys_groups,
-			   int GRP_RANDOM, int GRP_BBOX){
+static void get_poly_lines(int nt, SparseMatrix E, int ncomps, int *comps_ptr,
+                           int *comps, int *groups, SparseMatrix *poly_lines,
+                           int **polys_groups, int GRP_RANDOM, int GRP_BBOX) {
   /*============================================================
 
     polygon outlines 
 
     ============================================================*/
-  int i, *tlist, nz, ipoly, ipoly2, nnt, ii, jj, t1, t2, t, cur, next, nn, j, nlink, sta;
+  int i, *tlist, nz, ipoly, nnt, ii, jj, t1, t2, t, cur, next, nn, j, nlink, sta;
   int *elist, edim = 3;/* a list tell which vertex a particular vertex is linked with during poly construction.
 		since the surface is a cycle, each can only link with 2 others, the 3rd position is used to record how many links
 	      */
-  int *ie = E->ia, *je = E->ja, *e = E->a, n = E->m;
-  int *ia = NULL, *ja = NULL;
+  int *ie = E->ia, *je = E->ja, *e = E->a;
   SparseMatrix A;
-  int *gmask = NULL;
-
-
-  graph = NULL;/* we disable checking whether a polyline cross an edge for now due to issues with labels */
-  if (graph) {
-    assert(graph->m == n);
-    gmask = gv_calloc(n, sizeof(int));
-    for (i = 0; i < n; i++) gmask[i] = -1;
-    ia = graph->ia; ja = graph->ja;
-    edim = 5;/* we also store info about whether an edge of a polygon corresponds to a real edge or not. */
-  }
 
+  int *mask = gv_calloc(nt, sizeof(int));
   for (i = 0; i < nt; i++) mask[i] = -1;
   /* loop over every point in each connected component */
   elist = gv_calloc(nt * edim, sizeof(int));
@@ -541,18 +526,11 @@ static void get_poly_lines(int nt, SparseMatrix graph, SparseMatrix E, int ncomp
     for (j = comps_ptr[i]; j < comps_ptr[i+1]; j++){
       ii = comps[j];
 
-      if (graph){
-	for (jj = ia[ii]; jj < ia[ii+1]; jj++) gmask[ja[jj]] = ii;
-      }
-
       (*polys_groups)[i] = groups[ii];/* assign the grouping of each poly */
 
       /* skip the country formed by random points */
       if (groups[ii] == GRP_RANDOM || groups[ii] == GRP_BBOX) continue;
 
-      /* always skip bounding box */
-      if (groups[ii] == GRP_BBOX) continue;
-
       for (jj = ie[ii]; jj < ie[ii+1]; jj++){
 	if (groups[je[jj]] != groups[ii] && jj < nz - 1  && je[jj] == je[jj+1]){/* an triangle edge neighboring 2 triangles and two ends not in the same groups */
 	  t1 = e[jj];
@@ -560,27 +538,11 @@ static void get_poly_lines(int nt, SparseMatrix graph, SparseMatrix E, int ncomp
 
 	  nlink = elist[t1*edim + 2]%2;
 	  elist[t1*edim + nlink] = t2;/* t1->t2*/
-	  if (graph){
-	    if (gmask[je[jj]] == ii){/* a real edge */
-	      elist[t1*edim+nlink+3] = POLY_LINE_REAL_EDGE;
-	    } else {
-	      fprintf(stderr,"not real!!!\n");
-	      elist[t1*edim+nlink+3] = POLY_LINE_NOT_REAL_EDGE;
-	    }
-	  }
 	  elist[t1*edim + 2]++;
 
 	  nlink = elist[t2*edim + 2]%2;
 	  elist[t2*edim + nlink] = t1;/* t1->t2*/
 	  elist[t2*edim + 2]++;
-	  if (graph){
-	    if (gmask[je[jj]] == ii){/* a real edge */
-	      elist[t2*edim+nlink+3] = POLY_LINE_REAL_EDGE;
-	    } else {
-	      fprintf(stderr,"not real!!!\n");
-	      elist[t2*edim+nlink+3] = POLY_LINE_NOT_REAL_EDGE;
-	    }
-	  }
 
 	  tlist[nnt++] = t1; tlist[nnt++] = t2;
 	  jj++;
@@ -588,46 +550,20 @@ static void get_poly_lines(int nt, SparseMatrix graph, SparseMatrix E, int ncomp
       }
     }/* done poly edges for this component i */
 
-
-    /* debugging*/
-#ifdef DEBUG
-    /*
-    for (j = 0; j < nnt; j++) {
-      if (elist[tlist[j]*edim + 2]%2 != 0){
-	printf("wrong: elist[%d*edim+2] = %d\n",j,elist[tlist[j]*edim + 2]%);
-	assert(0);
-      }
-    }
-    */
-#endif
-
     /* form one or more (if there is a hole) polygon outlines for this component  */
     for (j = 0; j < nnt; j++){
       t = tlist[j];
       if (mask[t] != i){
 	cur = sta = t; mask[cur] = i;
 	next = neighbor(t, 1, edim, elist);
-	nlink = 1;
-	if (graph && neighbor(cur, 3, edim, elist) == POLY_LINE_NOT_REAL_EDGE){
-	  ipoly2 = - ipoly;
-	} else {
-	  ipoly2 = ipoly;
-	}
-	SparseMatrix_coordinate_form_add_entry(*poly_lines, i, cur, &ipoly2);
+	SparseMatrix_coordinate_form_add_entry(*poly_lines, i, cur, &ipoly);
 	while (next != sta){
 	  mask[next] = i;
 	  
-	  if (graph && neighbor(cur, nlink + 3, edim, elist) == POLY_LINE_NOT_REAL_EDGE){
-	    ipoly2 = -ipoly;
-	  } else {
-	    ipoly2 = ipoly;
-	  }
-	  SparseMatrix_coordinate_form_add_entry(*poly_lines, i, next, &ipoly2);
+	  SparseMatrix_coordinate_form_add_entry(*poly_lines, i, next, &ipoly);
 
 	  nn = neighbor(next, 0, edim, elist);
-	  nlink = 0;
 	  if (nn == cur) {
-	    nlink = 1;
 	    nn = neighbor(next, 1, edim, elist);
 	  }
 	  assert(nn != cur);
@@ -636,12 +572,7 @@ static void get_poly_lines(int nt, SparseMatrix graph, SparseMatrix E, int ncomp
 	  next = nn;
 	}
 
-	if (graph && neighbor(cur, nlink + 3, edim, elist) == POLY_LINE_NOT_REAL_EDGE){
-	  ipoly2 = -ipoly;
-	} else {
-	  ipoly2 = ipoly;
-	}
-	SparseMatrix_coordinate_form_add_entry(*poly_lines, i, sta, &ipoly2);/* complete a cycle by adding starting point */
+	SparseMatrix_coordinate_form_add_entry(*poly_lines, i, sta, &ipoly);/* complete a cycle by adding starting point */
 
 	ipoly++;
       }
@@ -655,6 +586,7 @@ static void get_poly_lines(int nt, SparseMatrix graph, SparseMatrix E, int ncomp
 
   free(tlist);
   free(elist);
+  free(mask);
 }
 
 static void cycle_print(int head, int *cycle, int *edge_table){
@@ -682,11 +614,12 @@ static int same_edge(int ecur, int elast, int *edge_table){
 	  || (edge_head(ecur) == edge_tail(elast) && edge_tail(ecur) == edge_head(elast));
 }
 
-static void get_polygon_solids(int nt, SparseMatrix E, int ncomps, int *comps_ptr, int *comps,
-			       int *mask, SparseMatrix *polys){
+static void get_polygon_solids(int nt, SparseMatrix E, int ncomps,
+                               int *comps_ptr, int *comps, SparseMatrix *polys)
+{
   /*============================================================
 
-    polygon slids that will be colored
+    polygon solids that will be colored
 
     ============================================================*/
   int *edge_table;/* a table of edges of the triangle graph. If two vertex u and v are connected and are adjacent to two triangles
@@ -703,7 +636,7 @@ static void get_polygon_solids(int nt, SparseMatrix E, int ncomps, int *comps_pt
 	       cycle[e][1] gives the next edge
 	     */
   int *edge_cycle_map, NOT_ON_CYCLE = -1;/* map an edge e to its position on cycle, unless it does not exist (NOT_ON_CYCLE) */
-  int *emask;/* whether an edge is seens this iter */
+  int *emask;/* whether an edge is seen this iter */
   enum {NO_DUPLICATE = -1};
   int *elist, edim = 3;/* a list tell which edge a particular vertex is linked with when a voro cell has been visited,
 		since the surface is a cycle, each vertex can only link with 2 edges, the 3rd position is used to record how many links
@@ -717,8 +650,6 @@ static void get_polygon_solids(int nt, SparseMatrix E, int ncomps, int *comps_pt
   ne = E->nz;
   edge_table = gv_calloc(ne * 2, sizeof(int));
 
-  for (i = 0; i < n; i++) mask[i] = -1;
-
   half_edges = SparseMatrix_new(n, n, 1, MATRIX_TYPE_INTEGER, FORMAT_COORD);
 
   ne = 0;
@@ -769,7 +700,6 @@ static void get_polygon_solids(int nt, SparseMatrix E, int ncomps, int *comps_pt
     if (DEBUG_CYCLE) fprintf(stderr, "\n ============  comp %d has %d members\n",i, comps_ptr[i+1]-comps_ptr[i]);
     for (k = comps_ptr[i]; k < comps_ptr[i+1]; k++){
       ii = comps[k];
-      mask[ii] = i;
       duplicate = NO_DUPLICATE;
       if (DEBUG_CYCLE) fprintf(stderr,"member = %d has %d neighbors\n",ii, ie[ii+1]-ie[ii]);
       for (j = ie[ii]; j < ie[ii+1]; j++){
@@ -936,16 +866,17 @@ static void get_polygon_solids(int nt, SparseMatrix E, int ncomps, int *comps_pt
   free(edge_table);
 }
 
-static void get_polygons(int n, int nrandom, int dim, SparseMatrix graph, int *grouping,
-			 int nt, struct Triangle *Tp, SparseMatrix E, int *nverts, double **x_poly, 
-			 SparseMatrix *poly_lines, SparseMatrix *polys, int **polys_groups, SparseMatrix *poly_point_map, SparseMatrix *country_graph){
+static void get_polygons(int n, int nrandom, int dim, int *grouping, int nt,
+                         struct Triangle *Tp, SparseMatrix E, int *nverts,
+                         double **x_poly, SparseMatrix *poly_lines,
+                         SparseMatrix *polys, int **polys_groups,
+                         SparseMatrix *poly_point_map,
+                         SparseMatrix *country_graph) {
   int i, j;
-  int *mask;
   int *groups;
   int maxgrp;
   int *comps = NULL, *comps_ptr = NULL, ncomps;
   int GRP_RANDOM, GRP_BBOX;
-  SparseMatrix B;
 
   assert(dim == 2);
   *nverts = nt;
@@ -966,7 +897,6 @@ static void get_polygons(int n, int nrandom, int dim, SparseMatrix graph, int *g
   }
   
   /* finding connected components: vertices that are connected in the triangle graph, as well as in the same group */
-  mask = gv_calloc(MAX(n + nrandom, 2 * nt), sizeof(int));
   conn_comp(n + nrandom, E, groups, poly_point_map);
 
   ncomps = (*poly_point_map)->m;
@@ -994,20 +924,19 @@ static void get_polygons(int n, int nrandom, int dim, SparseMatrix graph, int *g
     polygon outlines 
 
     ============================================================*/
-  get_poly_lines(nt, graph, E, ncomps, comps_ptr, comps, groups, mask, poly_lines, polys_groups, GRP_RANDOM, GRP_BBOX);
+  get_poly_lines(nt, E, ncomps, comps_ptr, comps, groups, poly_lines,
+                 polys_groups, GRP_RANDOM, GRP_BBOX);
 
   /*============================================================
 
     polygon solids
 
     ============================================================*/
-  get_polygon_solids(nt, E, ncomps, comps_ptr, comps, mask, polys);
+  get_polygon_solids(nt, E, ncomps, comps_ptr, comps, polys);
 
-  B = get_country_graph(n, E, groups, GRP_RANDOM, GRP_BBOX);
-  *country_graph = B;
+  *country_graph = get_country_graph(n, E, groups, GRP_RANDOM, GRP_BBOX);
 
   free(groups);
-  free(mask);
 }
 
 static void make_map_internal(bool include_OK_points,
@@ -1104,8 +1033,6 @@ static void make_map_internal(bool include_OK_points,
       qt = QuadTree_new_from_point_list(dim, n, max_qtree_level, x);
     }
   }
-  graph = NULL;
-
 
   /* generate random points for lake/sea effect */
   if (nrandom != 0){
@@ -1132,10 +1059,9 @@ static void make_map_internal(bool include_OK_points,
 	        fmax(boxsize[0] * 0.2, 2 * shore_depth_tol));
     }
     if (nrandom < 0) {
-      double n1, n2, area2;
-      area2 = (xmax[1] - xmin[1])*(xmax[0] - xmin[0]);
-      n1 = (int) area2/(shore_depth_tol*shore_depth_tol);
-      n2 = n*((int) area2/area);
+      const double area2 = (xmax[1] - xmin[1]) * (xmax[0] - xmin[0]);
+      const double n1 = floor(area2 / (shore_depth_tol * shore_depth_tol));
+      const double n2 = n * floor(area2 / area);
       nrandom = fmax(n1, n2);
     }
     srand(123);
@@ -1256,8 +1182,8 @@ static void make_map_internal(bool include_OK_points,
   if (get_tri(n + nrandom, dim2, xcombined, &nt, &Tp, &E) != 0) {
     goto done;
   }
-  get_polygons(n, nrandom, dim2, graph, grouping, nt, Tp, E, nverts, x_poly, poly_lines, polys, polys_groups,
-	       poly_point_map, country_graph);
+  get_polygons(n, nrandom, dim2, grouping, nt, Tp, E, nverts, x_poly,
+               poly_lines, polys, polys_groups, poly_point_map, country_graph);
 
   SparseMatrix_delete(E);
   free(Tp);
@@ -1298,7 +1224,7 @@ static void get_boundingbox(int n, int dim, double *x, double *width, double *bb
 
 void make_map_from_rectangle_groups(bool include_OK_points,
 				   int n, int dim, double *x, double *sizes, 
-				   int *grouping, SparseMatrix graph0, double bounding_box_margin, int nrandom, int *nart, int nedgep, 
+				   int *grouping, SparseMatrix graph, double bounding_box_margin, int nrandom, int *nart, int nedgep, 
 				   double shore_depth_tol,
 				   int *nverts, double **x_poly, 
 				   SparseMatrix *poly_lines, SparseMatrix *polys, int **polys_groups, SparseMatrix *poly_point_map, 
@@ -1365,7 +1291,6 @@ void make_map_from_rectangle_groups(bool include_OK_points,
   double point[2];
   int nadded[2];
   double delta[2];
-  SparseMatrix graph = graph0;
   double bbox[4];
 
   if (K < 0){
@@ -1415,10 +1340,9 @@ void make_map_from_rectangle_groups(bool include_OK_points,
     if (shore_depth_tol < 0) {
       shore_depth_tol = -(shore_depth_tol)*avgsz;
     } else if (shore_depth_tol == 0){
-      double area;
       get_boundingbox(n, dim, x, sizes, bbox);
-      area = (bbox[1] - bbox[0])*(bbox[3] - bbox[2]);
-      shore_depth_tol = sqrt(area/(double) n); 
+      const double area = (bbox[1] - bbox[0]) * (bbox[3] - bbox[2]);
+      shore_depth_tol = sqrt(area / n);
       if (Verbose) fprintf(stderr,"setting shore length ======%f\n",shore_depth_tol);
     } else {
     }
@@ -1492,7 +1416,6 @@ void make_map_from_rectangle_groups(bool include_OK_points,
     make_map_internal(include_OK_points, N, dim, X, groups, graph, bounding_box_margin, nrandom, nedgep,
 			    shore_depth_tol, nverts, x_poly, 
 			    poly_lines, polys, polys_groups, poly_point_map, country_graph, highlight_cluster);
-    if (graph != graph0) SparseMatrix_delete(graph);
     free(groups);
     free(X);
   }
