@@ -32,6 +32,7 @@
 #include <cgraph/alloc.h>
 #include <cgraph/cgraph.h>
 #include <cgraph/exit.h>
+#include <cgraph/gv_math.h>
 #include <cgraph/ingraphs.h>
 #include <cgraph/stack.h>
 #include <cgraph/unreachable.h>
@@ -57,12 +58,6 @@ typedef struct {
 #define N(n)  (((Agnodeinfo_t*)(n->base.data))->val)
 #define NEXTBLK(g)  (((Agraphinfo_t*)(g->base.data))->next)
 
-static int imin(int a, int b) {
-  if (a < b)
-    return a;
-  return b;
-}
-
 char **Files;
 int verbose;
 int silent;
