@@ -42,11 +42,10 @@ extern "C" {
     extern int chrtoi(const char *);
     extern char *fmtesq(const char *, const char *);
     extern char *fmtesc(const char *as);
-    extern char *fmtbuf(size_t n);
-    extern char *fmtquote(const char*, const char*, const char*, size_t);
+    extern char *fmtquote(const char *, const char *, const char *);
 
     extern int strmatch(char *, char *);
-    extern int strgrpmatch(char *, char *, int *, int, int);
+    extern int strgrpmatch(char *, char *, size_t *, int, int);
     extern void stresc(char *);
 
 #ifdef __cplusplus
