@@ -95,7 +95,7 @@ static double getRotation(block_t *sn, double x, double y, double theta) {
 	double r = sn->radius - rho;
 	double n_x = ND_pos(neighbor)[0];
 	if (COALESCED(sn) && -r < n_x) {
-	    double R = LEN(x, y);
+	    const double R = hypot(x, y);
 	    double n_y = ND_pos(neighbor)[1];
 	    double phi = atan2(n_y, n_x + r);
 	    double l = r - rho / cos(phi);
@@ -124,23 +124,14 @@ static void applyDelta(block_t * sn, double x, double y, double rotate)
     subg = sn->sub_graph;
 
     for (n = agfstnode(subg); n; n = agnxtnode(subg, n)) {
-	double X, Y;
 
-	if (rotate != 0) {
-	    double tmpX, tmpY;
-	    double cosR, sinR;
+	const double tmpX = ND_pos(n)[0];
+	const double tmpY = ND_pos(n)[1];
+	const double cosR = cos(rotate);
+	const double sinR = sin(rotate);
 
-	    tmpX = ND_pos(n)[0];
-	    tmpY = ND_pos(n)[1];
-	    cosR = cos(rotate);
-	    sinR = sin(rotate);
-
-	    X = tmpX * cosR - tmpY * sinR;
-	    Y = tmpX * sinR + tmpY * cosR;
-	} else {
-	    X = ND_pos(n)[0];
-	    Y = ND_pos(n)[1];
-	}
+	const double X = tmpX * cosR - tmpY * sinR;
+	const double Y = tmpX * sinR + tmpY * cosR;
 
 	/* translate */
 	ND_pos(n)[0] = X + x;
