@@ -1,6 +1,7 @@
 /**
  * @file
  * @brief Network Simplex algorithm for ranking nodes of a DAG, @ref rank, @ref rank2
+ * @ingroup common_render
  */
 
 /*************************************************************************
@@ -8,7 +9,7 @@
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
  * which accompanies this distribution, and is available at
- * http://www.eclipse.org/legal/epl-v10.html
+ * https://www.eclipse.org/legal/epl-v10.html
  *
  * Contributors: Details at https://graphviz.org
  *************************************************************************/
@@ -18,11 +19,14 @@
 #include <cgraph/exit.h>
 #include <cgraph/overflow.h>
 #include <cgraph/prisize_t.h>
+#include <cgraph/queue.h>
 #include <cgraph/streq.h>
 #include <common/render.h>
 #include <limits.h>
 #include <stdbool.h>
 #include <stddef.h>
+#include <stdint.h>
+#include <stdio.h>
 
 static void dfs_cutval(node_t * v, edge_t * par);
 static int dfs_range_init(node_t * v, edge_t * par, int low);
@@ -39,7 +43,6 @@ static void check_cycles(graph_t * g);
 
 static graph_t *G;
 static size_t N_nodes, N_edges;
-static int Maxrank;
 static size_t S_i;			/* search index for enter_edge */
 static int Search_size;
 #define SEARCHSIZE 30
@@ -49,9 +52,8 @@ static elist Tree_edge;
 static int add_tree_edge(edge_t * e)
 {
     node_t *n;
-    //fprintf(stderr,"add tree edge %p %s ", (void*)e, agnameof(agtail(e))) ; fprintf(stderr,"%s\n", agnameof(aghead(e))) ;
     if (TREE_EDGE(e)) {
-	agerr(AGERR, "add_tree_edge: missing tree edge\n");
+	agerrorf("add_tree_edge: missing tree edge\n");
 	return -1;
     }
     assert(Tree_edge.size <= INT_MAX);
@@ -66,7 +68,7 @@ static int add_tree_edge(edge_t * e)
     ND_tree_out(n).list[ND_tree_out(n).size++] = e;
     ND_tree_out(n).list[ND_tree_out(n).size] = NULL;
     if (ND_out(n).list[ND_tree_out(n).size - 1] == 0) {
-	agerr(AGERR, "add_tree_edge: empty outedge list\n");
+	agerrorf("add_tree_edge: empty outedge list\n");
 	return -1;
     }
     n = aghead(e);
@@ -74,7 +76,7 @@ static int add_tree_edge(edge_t * e)
     ND_tree_in(n).list[ND_tree_in(n).size++] = e;
     ND_tree_in(n).list[ND_tree_in(n).size] = NULL;
     if (ND_in(n).list[ND_tree_in(n).size - 1] == 0) {
-	agerr(AGERR, "add_tree_edge: empty inedge list\n");
+	agerrorf("add_tree_edge: empty inedge list\n");
 	return -1;
     }
     return 0;
@@ -98,7 +100,7 @@ static void invalidate_path(node_t *lca, node_t *to_node) {
 
         if (ND_lim(to_node) >= ND_lim(lca)) {
           if (to_node != lca)
-            agerr(AGERR, "invalidate_path: skipped over LCA\n");
+            agerrorf("invalidate_path: skipped over LCA\n");
           break;
         }
 
@@ -145,35 +147,34 @@ static
 void init_rank(void)
 {
     int i;
-    nodequeue *Q;
     node_t *v;
     edge_t *e;
 
-    Q = new_queue(N_nodes);
+    queue_t Q = queue_new(N_nodes);
     size_t ctr = 0;
 
     for (v = GD_nlist(G); v; v = ND_next(v)) {
 	if (ND_priority(v) == 0)
-	    enqueue(Q, v);
+	    queue_push(&Q, v);
     }
 
-    while ((v = dequeue(Q))) {
+    while ((v = queue_pop(&Q))) {
 	ND_rank(v) = 0;
 	ctr++;
 	for (i = 0; (e = ND_in(v).list[i]); i++)
 	    ND_rank(v) = MAX(ND_rank(v), ND_rank(agtail(e)) + ED_minlen(e));
 	for (i = 0; (e = ND_out(v).list[i]); i++) {
 	    if (--ND_priority(aghead(e)) <= 0)
-		enqueue(Q, aghead(e));
+		queue_push(&Q, aghead(e));
 	}
     }
     if (ctr != N_nodes) {
-	agerr(AGERR, "trouble in init_rank\n");
+	agerrorf("trouble in init_rank\n");
 	for (v = GD_nlist(G); v; v = ND_next(v))
 	    if (ND_priority(v))
 		agerr(AGPREV, "\t%s %d\n", agnameof(v), ND_priority(v));
     }
-    free_queue(Q);
+    queue_free(&Q);
 }
 
 static edge_t *leave_edge(void)
@@ -297,10 +298,15 @@ static void init_cutvalues(void)
 typedef struct subtree_s {
         node_t *rep;            /* some node in the tree */
         int    size;            /* total tight tree size */
-        int    heap_index;      /* required to find non-min elts when merged */
+        size_t    heap_index; ///< required to find non-min elts when merged
         struct subtree_s *par;  /* union find */
 } subtree_t;
 
+/// is this subtree stored in an STheap?
+static bool on_heap(const subtree_t *tree) {
+  return tree->heap_index != SIZE_MAX;
+}
+
 /* find initial tight subtrees */
 static int tight_subtree_search(Agnode_t *v, subtree_t *st)
 {
@@ -367,15 +373,15 @@ static subtree_t *STsetUnion(subtree_t *s0, subtree_t *s1)
   for (r0 = s0; r0->par && r0->par != r0; r0 = r0->par);
   for (r1 = s1; r1->par && r1->par != r1; r1 = r1->par);
   if (r0 == r1) return r0;  /* safety code but shouldn't happen */
-  assert(r0->heap_index > -1 || r1->heap_index > -1);
-  if (r1->heap_index == -1) r = r0;
-  else if (r0->heap_index == -1) r = r1;
+  assert(on_heap(r0) || on_heap(r1));
+  if (!on_heap(r1)) r = r0;
+  else if (!on_heap(r0)) r = r1;
   else if (r1->size < r0->size) r = r0;
   else r = r1;
 
   r0->par = r1->par = r;
   r->size = r0->size + r1->size;
-  assert(r->heap_index >= 0);
+  assert(on_heap(r));
   return r;
 }
 
@@ -420,21 +426,16 @@ static Agedge_t *inter_tree_edge(subtree_t *tree)
     return rv;
 }
 
-static
-int STheapsize(STheap_t *heap) { return heap->size; }
+static size_t STheapsize(const STheap_t *heap) { return heap->size; }
 
-static 
-void STheapify(STheap_t *heap, int i)
-{
-    int left, right, smallest;
+static void STheapify(STheap_t *heap, size_t i) {
     subtree_t **elt = heap->elt;
     do {
-        left = 2*(i+1)-1;
-        right = 2*(i+1);
-        if (left < heap->size && elt[left]->size < elt[i]->size) smallest = left;
-        else smallest = i;
+        const size_t left = 2 * (i + 1) - 1;
+        const size_t right = 2 * (i + 1);
+        size_t smallest = i;
+        if (left < heap->size && elt[left]->size < elt[smallest]->size) smallest = left;
         if (right < heap->size && elt[right]->size < elt[smallest]->size) smallest = right;
-        else smallest = i;
         if (smallest != i) {
             subtree_t *temp;
             temp = elt[i];
@@ -448,15 +449,12 @@ void STheapify(STheap_t *heap, int i)
     } while (i < heap->size);
 }
 
-static
-STheap_t *STbuildheap(subtree_t **elt, int size)
-{
-    int     i;
+static STheap_t *STbuildheap(subtree_t **elt, size_t size) {
     STheap_t *heap = gv_alloc(sizeof(STheap_t));
     heap->elt = elt;
     heap->size = size;
-    for (i = 0; i < heap->size; i++) heap->elt[i]->heap_index = i;
-    for (i = heap->size/2; i >= 0; i--)
+    for (size_t i = 0; i < heap->size; i++) heap->elt[i]->heap_index = i;
+    for (size_t i = heap->size / 2; i != SIZE_MAX; i--)
         STheapify(heap,i);
     return heap;
 }
@@ -466,7 +464,8 @@ subtree_t *STextractmin(STheap_t *heap)
 {
     subtree_t *rv;
     rv = heap->elt[0];
-    rv->heap_index = -1;
+    rv->heap_index = SIZE_MAX;
+      // mark this as not participating in the heap anymore
     heap->elt[0] = heap->elt[heap->size - 1];
     heap->elt[0]->heap_index = 0;
     heap->elt[heap->size -1] = rv;    /* needed to free storage later */
@@ -505,9 +504,7 @@ subtree_t *merge_trees(Agedge_t *e)   /* entering tree edge */
   t0 = STsetFind(agtail(e));
   t1 = STsetFind(aghead(e));
 
-  //fprintf(stderr,"merge trees of %d %d of %d, delta %d\n",t0->size,t1->size,N_nodes,delta);
-
-  if (t0->heap_index == -1) {   // move t0
+  if (!on_heap(t0)) { // move t0
     delta = SLACK(e);
     if (delta != 0)
       tree_adjust(t0->rep,NULL,delta);
@@ -533,21 +530,19 @@ subtree_t *merge_trees(Agedge_t *e)   /* entering tree edge */
 static
 int feasible_tree(void)
 {
-  Agnode_t *n;
   Agedge_t *ee;
-  subtree_t *tree0, *tree1;
-  int i, subtree_count = 0;
+  size_t subtree_count = 0;
   STheap_t *heap = NULL;
   int error = 0;
 
   /* initialization */
-  for (n = GD_nlist(G); n; n = ND_next(n)) {
+  for (Agnode_t *n = GD_nlist(G); n != NULL; n = ND_next(n)) {
       ND_subtree_set(n,0);
   }
 
   subtree_t **tree = gv_calloc(N_nodes, sizeof(subtree_t *));
   /* given init_rank, find all tight subtrees */
-  for (n = GD_nlist(G); n; n = ND_next(n)) {
+  for (Agnode_t *n = GD_nlist(G); n != NULL; n = ND_next(n)) {
         if (ND_subtree(n) == 0) {
                 tree[subtree_count] = find_tight_subtree(n);
                 if (tree[subtree_count] == NULL) {
@@ -561,12 +556,12 @@ int feasible_tree(void)
   /* incrementally merge subtrees */
   heap = STbuildheap(tree,subtree_count);
   while (STheapsize(heap) > 1) {
-    tree0 = STextractmin(heap);
+    subtree_t *tree0 = STextractmin(heap);
     if (!(ee = inter_tree_edge(tree0))) {
       error = 1;
       break;
     }
-    tree1 = merge_trees(ee);
+    subtree_t *tree1 = merge_trees(ee);
     if (tree1 == NULL) {
       error = 2;
       break;
@@ -576,7 +571,7 @@ int feasible_tree(void)
 
 end:
   free(heap);
-  for (i = 0; i < subtree_count; i++) free(tree[i]);
+  for (size_t i = 0; i < subtree_count; i++) free(tree[i]);
   free(tree);
   if (error) return error;
   assert(Tree_edge.size == N_nodes - 1);
@@ -653,7 +648,7 @@ update(edge_t * e, edge_t * f)
     cutvalue = ED_cutvalue(e);
     lca = treeupdate(agtail(f), aghead(f), cutvalue, 1);
     if (treeupdate(aghead(f), agtail(f), cutvalue, 0) != lca) {
-	agerr(AGERR, "update: mismatched lca in treeupdates\n");
+	agerrorf("update: mismatched lca in treeupdates\n");
 	return 2;
     }
 
@@ -669,12 +664,11 @@ update(edge_t * e, edge_t * f)
     return 0;
 }
 
-static void scan_and_normalize(void)
-{
+static int scan_and_normalize(void) {
     node_t *n;
 
     int Minrank = INT_MAX;
-    Maxrank = -INT_MAX;
+    int Maxrank = INT_MIN;
     for (n = GD_nlist(G); n; n = ND_next(n)) {
 	if (ND_node_type(n) == NORMAL) {
 	    Minrank = MIN(Minrank, ND_rank(n));
@@ -684,6 +678,7 @@ static void scan_and_normalize(void)
     for (n = GD_nlist(G); n; n = ND_next(n))
 	ND_rank(n) -= Minrank;
     Maxrank -= Minrank;
+    return Maxrank;
 }
 
 static void reset_lists(void) {
@@ -730,7 +725,19 @@ static void LR_balance(void)
     freeTreeList (G);
 }
 
-static int decreasingrankcmpf(node_t **n0, node_t **n1) {
+static int decreasingrankcmpf(const void *x, const void *y) {
+// Suppress Clang/GCC -Wcast-qual warning. Casting away const here is acceptable
+// as the later usage is const. We need the cast because the macros use
+// non-const pointers for genericity.
+#ifdef __GNUC__
+#pragma GCC diagnostic push
+#pragma GCC diagnostic ignored "-Wcast-qual"
+#endif
+  node_t **n0 = (node_t**)x;
+  node_t **n1 = (node_t**)y;
+#ifdef __GNUC__
+#pragma GCC diagnostic pop
+#endif
   if (ND_rank(*n1) < ND_rank(*n0)) {
     return -1;
   }
@@ -740,7 +747,19 @@ static int decreasingrankcmpf(node_t **n0, node_t **n1) {
   return 0;
 }
 
-static int increasingrankcmpf(node_t **n0, node_t **n1) {
+static int increasingrankcmpf(const void *x, const void *y) {
+// Suppress Clang/GCC -Wcast-qual warning. Casting away const here is acceptable
+// as the later usage is const. We need the cast because the macros use
+// non-const pointers for genericity.
+#ifdef __GNUC__
+#pragma GCC diagnostic push
+#pragma GCC diagnostic ignored "-Wcast-qual"
+#endif
+  node_t **n0 = (node_t **)x;
+  node_t **n1 = (node_t **)y;
+#ifdef __GNUC__
+#pragma GCC diagnostic pop
+#endif
   if (ND_rank(*n0) < ND_rank(*n1)) {
     return -1;
   }
@@ -759,12 +778,11 @@ static void TB_balance(void)
     int adj = 0;
     char *s;
 
-    scan_and_normalize();
+    const int Maxrank = scan_and_normalize();
 
     /* find nodes that are not tight and move to less populated ranks */
-    int *nrank = gv_calloc(Maxrank + 1, sizeof(int));
-    for (int i = 0; i <= Maxrank; i++)
-	nrank[i] = 0;
+    assert(Maxrank >= 0);
+    int *nrank = gv_calloc((size_t)Maxrank + 1, sizeof(int));
     if ( (s = agget(G,"TBbalance")) ) {
          if (streq(s,"min")) adj = 1;
          else if (streq(s,"max")) adj = 2;
@@ -784,8 +802,7 @@ static void TB_balance(void)
     }
     Tree_node.size = ii;
     qsort(Tree_node.list, Tree_node.size, sizeof(Tree_node.list[0]),
-        adj > 1? (int(*)(const void*,const void*))decreasingrankcmpf
-               : (int(*)(const void*,const void*))increasingrankcmpf);
+          adj > 1 ? decreasingrankcmpf: increasingrankcmpf);
     for (size_t i = 0; i < Tree_node.size; i++) {
         n = Tree_node.list[i];
         if (ND_node_type(n) == NORMAL)
@@ -964,7 +981,7 @@ int rank2(graph_t * g, int balance, int maxiter, int search_size)
 	LR_balance();
 	break;
     default:
-	scan_and_normalize();
+	(void)scan_and_normalize();
 	freeTreeList (G);
 	break;
     }
@@ -1009,12 +1026,12 @@ static void x_cutval(edge_t * f)
     sum = 0;
     for (i = 0; (e = ND_out(v).list[i]); i++)
 	if (sadd_overflow(sum, x_val(e, v, dir), &sum)) {
-	    agerr(AGERR, "overflow when computing edge weight sum\n");
+	    agerrorf("overflow when computing edge weight sum\n");
 	    graphviz_exit(EXIT_FAILURE);
 	}
     for (i = 0; (e = ND_in(v).list[i]); i++)
 	if (sadd_overflow(sum, x_val(e, v, dir), &sum)) {
-	    agerr(AGERR, "overflow when computing edge weight sum\n");
+	    agerrorf("overflow when computing edge weight sum\n");
 	    graphviz_exit(EXIT_FAILURE);
 	}
     ED_cutvalue(f) = sum;
@@ -1160,16 +1177,12 @@ void check_fast_node(node_t * n)
     assert(nptr != NULL);
 }
 
-static char* dump_node (node_t* n)
-{
-    static char buf[50];
-
+static void dump_node(FILE *sink, node_t *n) {
     if (ND_node_type(n)) {
-	snprintf(buf, sizeof(buf), "%p", n);
-	return buf;
+      fprintf(sink, "%p", n);
     }
     else
-	return agnameof(n);
+      fputs(agnameof(n), sink);
 }
 
 static void dump_graph (graph_t* g)
@@ -1180,13 +1193,19 @@ static void dump_graph (graph_t* g)
     FILE* fp = fopen ("ns.gv", "w");
     fprintf (fp, "digraph \"%s\" {\n", agnameof(g));
     for (n = GD_nlist(g); n; n = ND_next(n)) {
-	fprintf (fp, "  \"%s\"\n", dump_node(n));
+	fputs("  \"", fp);
+	dump_node(fp, n);
+	fputs("\"\n", fp);
     }
     for (n = GD_nlist(g); n; n = ND_next(n)) {
 	for (i = 0; (e = ND_out(n).list[i]); i++) {
-	    fprintf (fp, "  \"%s\"", dump_node(n));
+	    fputs("  \"", fp);
+	    dump_node(fp, n);
+	    fputs("\"", fp);
 	    w = aghead(e);
-	    fprintf (fp, " -> \"%s\"\n", dump_node(w));
+	    fputs(" -> \"", fp);
+	    dump_node(fp, w);
+	    fputs("\"\n", fp);
 	}
     }
 
