@@ -13,30 +13,22 @@
 #include <cgraph/alloc.h>
 #include <common/render.h>
 #include <common/pointset.h>
+#include <stddef.h>
 
 typedef struct {
     Dtlink_t link;
-    point id;
+    pointf id;
 } pair;
 
-static pair *mkPair(point p)
-{
+static pair *mkPair(pointf p) {
     pair *pp = gv_alloc(sizeof(pair));
     pp->id = p;
     return pp;
 }
 
-static void freePair(pair *pp, Dtdisc_t *disc) {
-    (void)disc;
-
-    free (pp);
-}
-
-static int cmppair(Dt_t * d, point * key1, point * key2, Dtdisc_t * disc)
-{
-    (void)d;
-    (void)disc;
-
+static int cmppair(void *k1, void *k2) {
+    const pointf *key1 = k1;
+    const pointf *key2 = k2;
     if (key1->x > key2->x)
 	return 1;
     else if (key1->x < key2->x)
@@ -51,11 +43,11 @@ static int cmppair(Dt_t * d, point * key1, point * key2, Dtdisc_t * disc)
 
 static Dtdisc_t intPairDisc = {
     offsetof(pair, id),
-    sizeof(point),
+    sizeof(pointf),
     offsetof(pair, link),
     0,
-    (Dtfree_f) freePair,
-    (Dtcompar_f) cmppair,
+    free,
+    cmppair,
 };
 
 PointSet *newPS(void)
@@ -68,8 +60,7 @@ void freePS(PointSet * ps)
     dtclose(ps);
 }
 
-void insertPS(PointSet * ps, point pt)
-{
+void insertPS(PointSet *ps, pointf pt) {
     pair *pp;
 
     pp = mkPair(pt);
@@ -77,27 +68,21 @@ void insertPS(PointSet * ps, point pt)
         free(pp);
 }
 
-void addPS(PointSet * ps, int x, int y)
-{
-    const point pt = {.x = x, .y = y};
+void addPS(PointSet *ps, double x, double y) {
+    const pointf pt = {.x = x, .y = y};
     pair *pp = mkPair(pt);
     if (dtinsert(ps, pp) != pp)
         free(pp);
 }
 
-int inPS(PointSet * ps, point pt)
-{
+int inPS(PointSet *ps, pointf pt) {
     pair p;
     p.id = pt;
     return dtsearch(ps, &p) ? 1 : 0;
 }
 
-int isInPS(PointSet * ps, int x, int y)
-{
-    pair p;
-    p.id.x = x;
-    p.id.y = y;
-    return dtsearch(ps, &p) ? 1 : 0;
+int isInPS(PointSet *ps, double x, double y) {
+  return inPS(ps, (pointf){.x = x, .y = y});
 }
 
 int sizeOf(PointSet * ps)
@@ -105,12 +90,11 @@ int sizeOf(PointSet * ps)
     return dtsize(ps);
 }
 
-point *pointsOf(PointSet * ps)
-{
-    int n = dtsize(ps);
-    point *pts = gv_calloc(n, sizeof(point));
+pointf *pointsOf(PointSet *ps) {
+    const size_t n = (size_t)dtsize(ps);
+    pointf *pts = gv_calloc(n, sizeof(pointf));
     pair *p;
-    point *pp = pts;
+    pointf *pp = pts;
 
     for (p = (pair *) dtflatten(ps); p;
 	 p = (pair *)dtlink(ps, p)) {
@@ -128,44 +112,28 @@ typedef struct {
 
 typedef struct {
     Dtdisc_t disc;
-    mpair *flist;
 } MPairDisc;
 
 static mpair *mkMPair(mpair *obj, MPairDisc *disc) {
-    mpair *ap;
-
-    if (disc->flist) {
-	ap = disc->flist;
-	disc->flist = (mpair *) (ap->link.right);
-    } else
-	ap = gv_alloc(sizeof(mpair));
+    (void)disc;
+    mpair *ap = gv_alloc(sizeof(mpair));
     ap->id = obj->id;
     ap->v = obj->v;
     return ap;
 }
 
-static void freeMPair(mpair *ap, MPairDisc *disc) {
-    ap->link.right = (Dtlink_t *) (disc->flist);
-    disc->flist = ap;
-}
-
 static Dtdisc_t intMPairDisc = {
     offsetof(mpair, id),
     sizeof(point),
     offsetof(mpair, link),
     (Dtmake_f) mkMPair,
-    (Dtfree_f) freeMPair,
-    (Dtcompar_f) cmppair,
+    free,
+    cmppair,
 };
 
 PointMap *newPM(void)
 {
-    MPairDisc *dp = gv_alloc(sizeof(MPairDisc));
-
-    dp->disc = intMPairDisc;
-    dp->flist = 0;
-
-    return (dtopen(&(dp->disc), Dtoset));
+  return dtopen(&intMPairDisc, Dtoset);
 }
 
 void clearPM(PointMap * ps)
@@ -175,16 +143,7 @@ void clearPM(PointMap * ps)
 
 void freePM(PointMap * ps)
 {
-    MPairDisc *dp = (MPairDisc *) (ps->disc);
-    mpair *p;
-    mpair *next;
-
     dtclose(ps);
-    for (p = dp->flist; p; p = next) {
-	next = (mpair *) (p->link.right);
-	free(p);
-    }
-    free(dp);
 }
 
 int insertPM(PointMap * pm, int x, int y, int value)
