@@ -14,13 +14,16 @@
 extern "C" {
 #endif
 
+#include <cgraph/list.h>
 #include <cgraph/queue.h>
 #include <dotgen/aspect.h>
 #include <stdbool.h>
 
+DEFINE_LIST(ints, int)
+
     extern void acyclic(Agraph_t *);
     extern void allocate_ranks(Agraph_t *);
-    extern void build_ranks(Agraph_t *, int);
+    extern void build_ranks(Agraph_t *, int, ints_t *);
     extern void build_skeleton(Agraph_t *, Agraph_t *);
     extern void checkLabelOrder (graph_t* g);
     extern void class1(Agraph_t *);
@@ -51,7 +54,6 @@ extern "C" {
     extern bool mergeable(edge_t *e, edge_t *f);
     extern void merge_chain(Agraph_t*, Agedge_t*, Agedge_t*, bool);
     extern void merge_oneway(Agedge_t *, Agedge_t *);
-    extern int ncross(Agraph_t *);
     extern Agedge_t *new_virtual_edge(Agnode_t *, Agnode_t *, Agedge_t *);
     extern bool nonconstraint_edge(Agedge_t *);
     extern void other_edge(Agedge_t *);
@@ -75,7 +77,6 @@ extern "C" {
     extern void dot_rank(Agraph_t *);
     extern void dot_sameports(Agraph_t *);
     extern void dot_splines(Agraph_t *);
-#undef extern
 
 #ifdef __cplusplus
 }
