@@ -236,11 +236,12 @@ prformat(void* vp, Sffmt_t* dp)
 			{
 				if (fmt->value.string)
 				{
-					size_t n = strlen(fmt->value.string);
-					if ((s = fmtbuf(n + 1)))
-						memcpy(s, fmt->value.string, n + 1);
+					char *const copy = vmstrdup(fmt->expr->vm, fmt->value.string);
+					if (copy == NULL) {
+						exerror("printf: out of memory");
+					}
 					vmfree(fmt->expr->vm, fmt->value.string);
-					fmt->value.string = s;
+					fmt->value.string = copy;
 				}
 				if (!fmt->value.string)
 					fmt->value.string = "";
@@ -270,12 +271,18 @@ prformat(void* vp, Sffmt_t* dp)
 	switch (dp->fmt)
 	{
 	case 'q':
-	case 'Q':
+	case 'Q': {
 		s = *(char**)vp;
-		*(char**)vp = fmtquote(s, "$'", "'", strlen(s));
+		char *quoted = fmtquote(s, "$'", "'");
+		*(char**)vp = vmstrdup(fmt->expr->vm, quoted);
+		free(quoted);
+		if (*(char**)vp == NULL) {
+			exerror("printf: out of memory");
+		}
 		dp->fmt = 's';
 		dp->size = -1;
 		break;
+	}
 	case 'S':
 		dp->flags &= ~SFFMT_LONG;
 		s = *(char**)vp;
@@ -322,18 +329,19 @@ prformat(void* vp, Sffmt_t* dp)
         if (txt.data == NULL) {
             exerror("printf: no time format provided");
         } else {
-            s = fmtbuf(TIME_LEN);
+            s = vmalloc(fmt->expr->vm, TIME_LEN);
             stm = localtime(&tm);
             char *format = malloc(sizeof(char) * (txt.size + 1));
-            if (format == NULL) {
+            if (s == NULL || format == NULL) {
+                vmfree(fmt->expr->vm, s);
                 exerror("printf: out of memory");
             } else {
                 strncpy(format, txt.data, txt.size);
                 format[txt.size] = '\0';
                 strftime(s, TIME_LEN, format, stm);
-                free(format);
                 *(char **)vp = s;
             }
+            free(format);
         }
 		dp->fmt = 's';
 		dp->size = -1;
@@ -518,10 +526,10 @@ static int scan(Expr_t *ex, Exnode_t *exnode, void *env, FILE *sp) {
 		}
 		fputs(v.string, sp);
 		rewind(sp);
-		n = sfscanf(sp, &fmt);
+		n = sfvscanf(sp, &fmt.fmt);
 		fclose(sp);
 	} else {
-		n = sfscanf(sp, &fmt);
+		n = sfvscanf(sp, &fmt.fmt);
 	}
 	if (fmt.actuals && !*fmt.fmt.form)
 		exerror("scanf: %s: too many arguments", fmt.actuals->data.operand.left->data.variable.symbol->name);
@@ -746,17 +754,17 @@ static char *str_mpy(Expr_t *ex, const char *l, const char *r) {
  * Add replacement string.
  * \digit is replaced with a subgroup match, if any.
  */
-static void replace(agxbuf *s, char *base, char *repl, int ng, int *sub) {
+static void replace(agxbuf *s, char *base, char *repl, int ng, size_t *sub) {
   char c;
-  int idx, offset;
+  int idx;
 
   while ((c = *repl++)) {
     if (c == '\\') {
       if ((c = *repl) && gv_isdigit(c)) {
         idx = c - '0';
         if (idx < ng) {
-          offset = sub[2 * idx];
-          agxbput_n(s, base + offset, (size_t)(sub[2 * idx + 1] - offset));
+          const size_t offset = sub[2 * idx];
+          agxbput_n(s, base + offset, sub[2 * idx + 1] - offset);
         }
         repl++;
       } else {
@@ -768,8 +776,6 @@ static void replace(agxbuf *s, char *base, char *repl, int ng, int *sub) {
   }
 }
 
-#define MCNT(s) (sizeof(s)/(2*sizeof(int)))
-
 static void
 addItem (Dt_t* arr, Extype_t v, char* tok)
 {
@@ -889,7 +895,7 @@ static Extype_t exsub(Expr_t *ex, Exnode_t *exnode, void *env, bool global) {
 	char *p;
 	char *s;
 	Extype_t v;
-	int sub[20];
+	size_t sub[20];
 	int flags = 0;
 	int ng;
 
@@ -925,7 +931,7 @@ static Extype_t exsub(Expr_t *ex, Exnode_t *exnode, void *env, bool global) {
 		return v;
 	}
 
-	ng = strgrpmatch(str, pat, sub, MCNT(sub), flags);
+	ng = strgrpmatch(str, pat, sub, sizeof(sub) / (sizeof(sub[0]) * 2), flags);
 	if (ng == 0) {
 		v.string = vmstrdup(ex->ve, str);
 		return v;
@@ -938,7 +944,7 @@ static Extype_t exsub(Expr_t *ex, Exnode_t *exnode, void *env, bool global) {
 
 	agxbuf buffer = {0};
 
-	agxbput_n(&buffer, str, (size_t)sub[0]);
+	agxbput_n(&buffer, str, sub[0]);
 
 	if (repl) {
 		replace(&buffer, str, repl, ng, sub);
@@ -946,8 +952,8 @@ static Extype_t exsub(Expr_t *ex, Exnode_t *exnode, void *env, bool global) {
 
 	s = str + sub[1];
 	if (global) {
-		while ((ng = strgrpmatch(s, pat, sub, MCNT(sub), flags))) {
-			agxbput_n(&buffer, s, (size_t)sub[0]);
+		while ((ng = strgrpmatch(s, pat, sub, sizeof(sub) / (sizeof(sub[0]) * 2), flags))) {
+			agxbput_n(&buffer, s, sub[0]);
 			if (repl) {
 				replace(&buffer, s, repl, ng, sub);
 			}
