@@ -17,16 +17,11 @@ extern "C" {
  * grammar support routines
  * stuffed in a header so exparse.y can work
  * with both yacc and bison
- * sometimes free stuff can cost a lot
  */
 
 #if !defined(_EXGRAM_H) && ( defined(MINTOKEN) || defined(YYTOKENTYPE) )
 #define _EXGRAM_H
 
-#if !defined(_EXPARSE_H)
-#define _EXPARSE_H
-#endif
-
 #include <cgraph/agxbuf.h>
 #include <cgraph/gv_ctype.h>
 #include <expr/exlib.h>
@@ -985,12 +980,9 @@ static void checkName(Exid_t * id)
 	}
 }
 
-static int
-cmpKey(Dt_t * d, Extype_t * key1, Extype_t * key2, Dtdisc_t * disc) 
-{
-	(void)d;
-	(void)disc;
-
+static int cmpKey(void *k1, void *k2) {
+	const Extype_t *key1 = k1;
+	const Extype_t *key2 = k2;
 	if (key1->integer < key2->integer)
 	    return -1;
 	else if (key1->integer > key2->integer)
