@@ -30,6 +30,7 @@
 
 #include "config.h"
 #include <assert.h>
+#include <float.h>
 #include <limits.h>
 #include <inttypes.h>
 #include <assert.h>
@@ -73,17 +74,17 @@ typedef struct {
  * node's connected component.
  * Also, entire layout is translated to origin.
  */
-static void finalCC(graph_t *g, size_t c_cnt, graph_t **cc, point *pts,
+static void finalCC(graph_t *g, size_t c_cnt, graph_t **cc, pointf *pts,
                     graph_t *rg, layout_info* infop) {
     attrsym_t * G_width = infop->G_width;
     attrsym_t * G_height = infop->G_height;
     graph_t *cg;
     boxf bb;
     boxf bbf;
-    point pt;
+    pointf pt;
     int margin;
     graph_t **cp = cc;
-    point *pp = pts;
+    pointf *pp = pts;
     int isRoot = rg == infop->rootg;
     int isEmpty = 0;
 
@@ -119,11 +120,8 @@ static void finalCC(graph_t *g, size_t c_cnt, graph_t **cc, point *pts,
     }
 
     if (GD_label(rg)) {
-	point p;
-
 	isEmpty = 0;
-	PF2P(GD_label(rg)->dimen, p);
-	double d = p.x - (bb.UR.x - bb.LL.x);
+	double d = round(GD_label(rg)->dimen.x) - (bb.UR.x - bb.LL.x);
 	if (d > 0) {		/* height of label added below */
 	    d /= 2;
 	    bb.LL.x -= d;
@@ -147,7 +145,7 @@ static void finalCC(graph_t *g, size_t c_cnt, graph_t **cc, point *pts,
 	cp = cc;
 	pp = pts;
 	while ((cg = *cp++)) {
-	    point p;
+	    pointf p;
 	    node_t *n;
 	    pointf del;
 
@@ -415,7 +413,7 @@ static graph_t *deriveGraph(graph_t * g, layout_info * infop)
 
     /* create derived nodes from clusters */
     for (i = 1; i <= GD_n_cluster(g); i++) {
-	boxf fix_bb = {{ MAXDOUBLE, MAXDOUBLE },{ -MAXDOUBLE, -MAXDOUBLE }};
+	boxf fix_bb = {{DBL_MAX, DBL_MAX}, {-DBL_MAX, -DBL_MAX}};
 	subg = GD_clust(g)[i];
 
 	do_graph_label(subg);
@@ -810,7 +808,7 @@ setClustNodes(graph_t* root)
  */
 static int layout(graph_t * g, layout_info * infop)
 {
-    point *pts = NULL;
+    pointf *pts = NULL;
     graph_t *dg;
     node_t *dn;
     node_t *n;
