@@ -3,7 +3,7 @@
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
  * which accompanies this distribution, and is available at
- * http://www.eclipse.org/legal/epl-v10.html
+ * https://www.eclipse.org/legal/epl-v10.html
  *
  * Contributors: Details at https://graphviz.org
  *************************************************************************/
@@ -12,6 +12,7 @@
 
 #include	<stdbool.h>
 #include	<stddef.h>
+#include	<stdio.h>
 #include	<string.h>
 #include	<unistd.h>
 
@@ -20,7 +21,6 @@
 #endif
 
 #include	<cgraph/agxbuf.h>
-#include        <common/memory.h>
 #include        <common/types.h>
 #include        <gvc/gvc.h>
 #include        <gvc/gvplugin.h>
@@ -154,7 +154,7 @@ gvplugin_library_t *gvplugin_library_load(GVC_t *gvc, const char *pathname) {
 #ifdef ENABLE_LTDL
     lt_dlhandle hndl;
     lt_ptr ptr;
-    char *s, *sym;
+    char *s;
     size_t len;
     char *libdir;
     char *suffix = "_LTX_library";
@@ -175,7 +175,7 @@ gvplugin_library_t *gvplugin_library_load(GVC_t *gvc, const char *pathname) {
     }
 
     if (lt_dlinit()) {
-        agerr(AGERR, "failed to init libltdl\n");
+        agerrorf("failed to init libltdl\n");
         agxbfree(&fullpath);
         return NULL;
     }
@@ -183,10 +183,10 @@ gvplugin_library_t *gvplugin_library_load(GVC_t *gvc, const char *pathname) {
     hndl = lt_dlopen(p);
     if (!hndl) {
         if (access(p, R_OK) == 0) {
-            agerr(AGWARN, "Could not load \"%s\" - %s\n", p, "It was found, so perhaps one of its dependents was not.  Try ldd.");
+            agwarningf("Could not load \"%s\" - %s\n", p, "It was found, so perhaps one of its dependents was not.  Try ldd.");
         }
         else {
-            agerr(AGWARN, "Could not load \"%s\" - %s\n", p, lt_dlerror());
+            agwarningf("Could not load \"%s\" - %s\n", p, lt_dlerror());
         }
         agxbfree(&fullpath);
         return NULL;
@@ -201,11 +201,11 @@ gvplugin_library_t *gvplugin_library_load(GVC_t *gvc, const char *pathname) {
 #else
     if (len < strlen("/libgvplugin_x")) {
 #endif
-        agerr(AGERR, "invalid plugin path \"%s\"\n", p);
+        agerrorf("invalid plugin path \"%s\"\n", p);
         agxbfree(&fullpath);
         return NULL;
     }
-    sym = gmalloc(len + strlen(suffix) + 1);
+    char *sym = gv_alloc(len + strlen(suffix) + 1);
 #if defined(_WIN32) && !defined(__MINGW32__) && !defined(__CYGWIN__)
     strcpy(sym, s + 1);         /* strip leading "/"  */
 #else
@@ -220,7 +220,7 @@ gvplugin_library_t *gvplugin_library_load(GVC_t *gvc, const char *pathname) {
 
     ptr = lt_dlsym(hndl, sym);
     if (!ptr) {
-        agerr(AGERR, "failed to resolve %s in %s\n", sym, p);
+        agerrorf("failed to resolve %s in %s\n", sym, p);
         free(sym);
         agxbfree(&fullpath);
         return NULL;
@@ -229,7 +229,7 @@ gvplugin_library_t *gvplugin_library_load(GVC_t *gvc, const char *pathname) {
     agxbfree(&fullpath);
     return (gvplugin_library_t *)ptr;
 #else
-    agerr(AGERR, "dynamic loading not available\n");
+    agerrorf("dynamic loading not available\n");
     return NULL;
 #endif
 }
@@ -247,8 +247,8 @@ gvplugin_library_t *gvplugin_library_load(GVC_t *gvc, const char *pathname) {
 		png:gd:gd
       
 */
-gvplugin_available_t *gvplugin_load(GVC_t * gvc, api_t api, const char *str)
-{
+gvplugin_available_t *gvplugin_load(GVC_t *gvc, api_t api, const char *str,
+                                    FILE *debug) {
     gvplugin_available_t *pnext, *rv;
     gvplugin_library_t *library;
     gvplugin_api_t *apis;
@@ -275,6 +275,8 @@ gvplugin_available_t *gvplugin_load(GVC_t * gvc, api_t api, const char *str)
         }
     }
 
+    agxbuf diag = {0}; // diagnostic messages
+
     /* iterate the linked list of plugins for this api */
     for (pnext = gvc->apis[api]; pnext; pnext = pnext->next) {
         const strview_t typ = strview(pnext->typestr, ':');
@@ -284,10 +286,17 @@ gvplugin_available_t *gvplugin_load(GVC_t * gvc, api_t api, const char *str)
             dep = strview(typ.data + typ.size + strlen(":"), '\0');
         }
 
-        if (!strview_eq(typ, reqtyp))
+        if (!strview_eq(typ, reqtyp)) {
+            agxbprint(&diag, "# type \"%.*s\" did not match \"%.*s\"\n",
+                      (int)typ.size, typ.data, (int)reqtyp.size, reqtyp.data);
             continue;           /* types empty or mismatched */
+        }
         if (dep.data && reqdep.data) {
             if (!strview_eq(dep, reqdep)) {
+                agxbprint(&diag,
+                          "# dependencies \"%.*s\" did not match \"%.*s\"\n",
+                          (int)dep.size, dep.data, (int)reqdep.size,
+                          reqdep.data);
                 continue;           /* dependencies not empty, but mismatched */
             }
         }
@@ -295,8 +304,12 @@ gvplugin_available_t *gvplugin_load(GVC_t * gvc, api_t api, const char *str)
             // found with no packagename constraints, or with required matching packagename
 
             if (dep.data && apidep != api) // load dependency if needed, continue if can't find
-                if (!gvplugin_load(gvc, apidep, dep.data))
+                if (!gvplugin_load(gvc, apidep, dep.data, debug)) {
+                    agxbprint(&diag,
+                              "# plugin loading of dependency \"%.*s\" failed\n",
+                              (int)dep.size, dep.data);
                     continue;
+                }
             break;
         }
     }
@@ -320,12 +333,19 @@ gvplugin_available_t *gvplugin_load(GVC_t * gvc, api_t api, const char *str)
     }
 
     /* one last check for successful load */
-    if (rv && rv->typeptr == NULL)
+    if (rv && rv->typeptr == NULL) {
+        agxbprint(&diag, "# unsuccessful plugin load\n");
         rv = NULL;
+    }
 
     if (rv && gvc->common.verbose >= 1)
         fprintf(stderr, "Using %s: %s:%s\n", api_names[api], rv->typestr, rv->package->name);
 
+    if (debug != NULL) {
+        fputs(agxbuse(&diag), debug);
+    }
+    agxbfree(&diag);
+
     gvc->api[api] = rv;
     return rv;
 }
@@ -406,7 +426,7 @@ char **gvPluginList(GVC_t *gvc, const char *kind, int *sz) {
             break;
     }
     if (api == ARRAY_SIZE(api_names)) {
-        agerr(AGERR, "unrecognized api name \"%s\"\n", kind);
+        agerrorf("unrecognized api name \"%s\"\n", kind);
         return NULL;
     }
 
