@@ -59,11 +59,9 @@ typedef struct {
     int t;
 } item;
 
-static int cmpItem(Dt_t * d, int p1[], int p2[], Dtdisc_t * disc)
-{
-    (void)d;
-    (void)disc;
-
+static int cmpItem(void *item1, void *item2) {
+    const int *p1 = item1;
+    const int *p2 = item2;
     if (p1[0] < p2[0]) return -1;
     if (p1[0] > p2[0]) return 1;
     if (p1[1] < p2[1]) return -1;
@@ -84,18 +82,13 @@ static void *newItem(item *objp, Dtdisc_t *disc) {
     return newp;
 }
 
-static void freeItem(item *obj, Dtdisc_t *disc) {
-    (void)disc;
-    free(obj);
-}
-
 static Dtdisc_t itemdisc = {
     .key = offsetof(item, a),
     .size = 2 * sizeof(int),
     .link = offsetof(item, link),
     .makef = (Dtmake_f)newItem,
-    .freef = (Dtfree_f)freeItem,
-    .comparf = (Dtcompar_f)cmpItem,
+    .freef = free,
+    .comparf = cmpItem,
 };
 
 static void addMap(Dt_t * map, int a, int b, int t)
@@ -160,11 +153,9 @@ typedef struct {
     int j;
 } Ipair;
 
-static int cmpIpair(Dt_t * d, int *p1, int *p2, Dtdisc_t * disc)
-{
-    (void)d;
-    (void)disc;
-
+static int cmpIpair(void *pair1, void *pair2) {
+    const int *p1 = pair1;
+    const int *p2 = pair2;
     if (*p1 < *p2) {
         return -1;
     }
@@ -184,18 +175,13 @@ static void *newIpair(Ipair *objp, Dtdisc_t *disc) {
     return newp;
 }
 
-static void freeIpair(Ipair *obj, Dtdisc_t *disc) {
-    (void)disc;
-    free(obj);
-}
-
 static Dtdisc_t ipairdisc = {
     .key = offsetof(Ipair, i),
     .size = sizeof(int),
     .link = offsetof(Ipair, link),
     .makef = (Dtmake_f)newIpair,
-    .freef = (Dtfree_f)freeIpair,
-    .comparf = (Dtcompar_f)cmpIpair,
+    .freef = free,
+    .comparf = cmpIpair,
 };
 
 static void vmapAdd(Dt_t * map, int i, int j)
@@ -442,8 +428,8 @@ static boxf bbox(Ppoly_t** obsp, int npoly, int *np)
     pointf p;
     Ppoly_t* obs;
 
-    bb.LL.x = bb.LL.y = MAXDOUBLE;
-    bb.UR.x = bb.UR.y = -MAXDOUBLE;
+    bb.LL.x = bb.LL.y = DBL_MAX;
+    bb.UR.x = bb.UR.y = -DBL_MAX;
 
     for (i = 0; i < npoly; i++) {
 	obs = *obsp++;
@@ -715,10 +701,9 @@ static Ppoint_t tweakEnd(Ppoly_t poly, size_t s, Ppoint_t q) {
 	prv = poly.ps[s - 1];
     if (EQPT(q, nxt) || EQPT(q, prv) ){
 	Ppoint_t m;
-	double d;
 	m.x = (nxt.x + prv.x)/2.0 - p.x;
 	m.y = (nxt.y + prv.y)/2.0 - p.y;
-	d = LEN(m.x,m.y);
+	const double d = hypot(m.x, m.y);
 	p.x += 0.1*m.x/d;
 	p.y += 0.1*m.y/d;
     }
