@@ -117,17 +117,9 @@ static void *newitem(edgeitem *obj, Dtdisc_t *disc) {
     return newp;
 }
 
-static void freeitem(edgeitem *obj, Dtdisc_t *disc) {
-    (void)disc;
-    free(obj);
-}
-
-static int
-cmpitems(Dt_t * d, edgeinfo * key1, edgeinfo * key2, Dtdisc_t * disc)
-{
-    (void)d;
-    (void)disc;
-
+static int cmpitems(void *k1, void *k2) {
+    const edgeinfo *key1 = k1;
+    const edgeinfo *key2 = k2;
     if (key1->n1 > key2->n1)
 	return 1;
     if (key1->n1 < key2->n1)
@@ -161,8 +153,8 @@ Dtdisc_t edgeItemDisc = {
     sizeof(edgeinfo),
     offsetof(edgeitem, link),
     (Dtmake_f) newitem,
-    (Dtfree_f) freeitem,
-    (Dtcompar_f) cmpitems,
+    free,
+    cmpitems,
 };
 
 /* equivEdge:
@@ -357,7 +349,7 @@ Ppoly_t *makeObstacle(node_t * n, expand_t* pmargin, bool isOrtho)
 		/* For fixedshape, we can't use the width and height, as this includes
 		 * the label. We only want to use the actual node shape.
 		 */
-	    if (poly->option & FIXEDSHAPE) {
+	    if (poly->option.fixedshape) {
 		b = polyBB (poly);
 		vs[0] = b.LL;
 		vs[1].x = b.UR.x;
@@ -430,7 +422,7 @@ Ppoly_t *makeObstacle(node_t * n, expand_t* pmargin, bool isOrtho)
 			polyp.y = verts[j].y + ymargin;
 		    }
 		    else {
-			double h = LEN(verts[j].x,verts[j].y);
+			const double h = hypot(verts[j].x, verts[j].y);
 			polyp.x = verts[j].x * (1.0 + margin.x/h);
 			polyp.y = verts[j].y * (1.0 + margin.y/h);
 		    }
