@@ -63,9 +63,9 @@ static const unsigned char *setclass(const unsigned char *form, bool *accept) {
 
 /**
  * @param f file to be scanned
- * @param args
+ * @param ft Formatting instructions
  */
-int sfvscanf(FILE *f, va_list args) {
+int sfvscanf(FILE *f, Sffmt_t *ft) {
     int inp, shift, base, width;
     ssize_t size;
     int fmt, flags, dot, n_assign, v, n, n_input;
@@ -73,7 +73,6 @@ int sfvscanf(FILE *f, va_list args) {
     char accept[SF_MAXDIGITS];
 
     Argv_t argv;
-    Sffmt_t *ft;
 
     int argp, argn;
 
@@ -94,13 +93,12 @@ int sfvscanf(FILE *f, va_list args) {
     inp = -1;
 
     const char *form;
-    argv.ft = va_arg(args, Sffmt_t *);
+    argv.ft = ft;
 
     form = argv.ft->form;
-    va_copy(args, argv.ft->args);
     argn = -1;
 
-    ft = argv.ft;
+    assert(ft != NULL && ft->extf != NULL);
 
   loop_fmt:
     while ((fmt = *form++)) {
@@ -171,24 +169,15 @@ int sfvscanf(FILE *f, va_list args) {
 			n_str = (form - 1) - t_str;
 		    else {
 			t_str = _Sffmtintf(t_str + 1, &n);
-			n = FP_SET(-1, argn);
+			FP_SET(-1, argn);
 
-			if (ft && ft->extf) {
-			    FMTSET(ft, form, args,
-				   LEFTP, 0, 0, 0, 0, 0, NULL, 0);
-			    n = ft->extf(&argv, ft);
-			    if (n < 0)
-				goto done;
-			    if (!(ft->flags & SFFMT_VALUE))
-				goto t_arg;
-			    if ((t_str = argv.s) &&
-				(n_str = (int) ft->size) < 0)
-				n_str = (ssize_t)strlen(t_str);
-			} else {
-			  t_arg:
-			    if ((t_str = va_arg(args, char *)))
-				 n_str = (ssize_t)strlen(t_str);
-			}
+			FMTSET(ft, form, LEFTP, 0, 0, 0, 0, 0, NULL, 0);
+			n = ft->extf(&argv, ft);
+			if (n < 0)
+			    goto done;
+			assert(ft->flags & SFFMT_VALUE);
+			if ((t_str = argv.s) && (n_str = (int)ft->size) < 0)
+			    n_str = (ssize_t)strlen(t_str);
 		    }
 		    goto loop_flags;
 		default:
@@ -210,17 +199,11 @@ int sfvscanf(FILE *f, va_list args) {
 		form = _Sffmtintf(form + 1, &n);
 		n = FP_SET(-1, argn);
 
-		if (ft && ft->extf) {
-		    FMTSET(ft, form, args, '.', dot, 0, 0, 0, 0,
-			   NULL, 0);
-		    if (ft->extf(&argv, ft) < 0)
-			goto done;
-		    if (ft->flags & SFFMT_VALUE)
-			v = argv.i;
-		    else
-			v = (dot <= 2) ? va_arg(args, int) : 0;
-		} else
-		    v = (dot <= 2) ? va_arg(args, int) : 0;
+		FMTSET(ft, form, '.', dot, 0, 0, 0, 0, NULL, 0);
+		if (ft->extf(&argv, ft) < 0)
+		    goto done;
+		assert(ft->flags & SFFMT_VALUE);
+		v = argv.i;
 		if (v < 0)
 		    v = 0;
 		goto dot_set;
@@ -258,17 +241,11 @@ int sfvscanf(FILE *f, va_list args) {
 		form = _Sffmtintf(form + 1, &n);
 		n = FP_SET(-1, argn);
 
-		if (ft && ft->extf) {
-		    FMTSET(ft, form, args, 'I', sizeof(int), 0, 0, 0, 0,
-			   NULL, 0);
-		    if (ft->extf(&argv, ft) < 0)
-			goto done;
-		    if (ft->flags & SFFMT_VALUE)
-			size = argv.i;
-		    else
-			size = va_arg(args, int);
-		} else
-		    size = va_arg(args, int);
+		FMTSET(ft, form, 'I', sizeof(int), 0, 0, 0, 0, NULL, 0);
+		if (ft->extf(&argv, ft) < 0)
+		    goto done;
+		assert(ft->flags & SFFMT_VALUE);
+		size = argv.i;
 	    }
 	    goto loop_flags;
 
@@ -328,31 +305,26 @@ int sfvscanf(FILE *f, va_list args) {
 	}
 
 	argp = FP_SET(argp, argn);
-	if (ft && ft->extf) {
-	    FMTSET(ft, form, args, fmt, size, flags, width, 0, base, t_str,
-		   n_str);
-	    v = ft->extf(&argv, ft);
+	FMTSET(ft, form, fmt, size, flags, width, 0, base, t_str, n_str);
+	v = ft->extf(&argv, ft);
 
-	    if (v < 0)
-		goto done;
-	    else if (v == 0) {	/* extf did not use input stream */
-		FMTGET(ft, form, args, fmt, size, flags, width, n, base);
-		if ((ft->flags & SFFMT_VALUE) && !(ft->flags & SFFMT_SKIP))
-		    value = argv.vp;
-	    } else {		/* v > 0: number of input bytes consumed */
-		n_input += v;
-		if (!(ft->flags & SFFMT_SKIP))
-		    n_assign += 1;
-		continue;
-	    }
+	if (v < 0)
+	    goto done;
+	else if (v == 0) { // extf did not use input stream
+	    FMTGET(ft, form, fmt, size, flags, width, n, base);
+	    if ((ft->flags & SFFMT_VALUE) && !(ft->flags & SFFMT_SKIP))
+		value = argv.vp;
+	} else { // v > 0: number of input bytes consumed
+	    n_input += v;
+	    if (!(ft->flags & SFFMT_SKIP))
+		n_assign += 1;
+	    continue;
 	}
 
 	if (_Sftype[fmt] == 0)	/* unknown pattern */
 	    continue;
 
-	/* get the address to assign value */
-	if (!value && !(flags & SFFMT_SKIP))
-	    value = va_arg(args, void *);
+	assert(!(!value && !(flags & SFFMT_SKIP)));
 
 	if (fmt == 'n') {	/* return length of consumed input */
 	    if (sizeof(long) > sizeof(int) && FMTCMP(size, long, long long))
