@@ -3,7 +3,7 @@
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
  * which accompanies this distribution, and is available at
- * http://www.eclipse.org/legal/epl-v10.html
+ * https://www.eclipse.org/legal/epl-v10.html
  *
  * Contributors: Details at https://graphviz.org
  *************************************************************************/
@@ -12,6 +12,7 @@
 #include <cgraph/agxbuf.h>
 #include <cgraph/alloc.h>
 #include <cgraph/startswith.h>
+#include <cgraph/unreachable.h>
 #include <sparse/general.h>
 #include <sparse/DotIO.h>
 #include <sparse/clustering.h>
@@ -152,7 +153,7 @@ SparseMatrix SparseMatrix_import_dot(Agraph_t *g, int dim,
 	  nitems = sscanf(pval, "%lf,%lf", &xx, &yy);
 	  if (nitems != 2) {
             has_positions = false;
-            agerr(AGERR, "Node \"%s\" pos has %d < 2 values", agnameof(n), nitems);
+            agerrorf("Node \"%s\" pos has %d < 2 values", agnameof(n), nitems);
 	  }
 	  (*x)[i*dim] = xx;
 	  (*x)[i*dim+1] = yy;
@@ -160,7 +161,7 @@ SparseMatrix SparseMatrix_import_dot(Agraph_t *g, int dim,
 	  nitems = sscanf(pval, "%lf,%lf,%lf", &xx, &yy, &zz);
 	  if (nitems != 3) {
             has_positions = false;
-            agerr(AGERR, "Node \"%s\" pos has %d < 3 values", agnameof(n), nitems);
+            agerrorf("Node \"%s\" pos has %d < 3 values", agnameof(n), nitems);
 	  }
 	  (*x)[i*dim] = xx;
 	  (*x)[i*dim+1] = yy;
@@ -169,7 +170,7 @@ SparseMatrix SparseMatrix_import_dot(Agraph_t *g, int dim,
 	  nitems = sscanf(pval, "%lf,%lf,%lf,%lf", &xx, &yy, &zz,&ww);
 	  if (nitems != 4) {
             has_positions = false;
-            agerr(AGERR, "Node \"%s\" pos has %d < 4 values", agnameof(n), nitems);
+            agerrorf("Node \"%s\" pos has %d < 4 values", agnameof(n), nitems);
 	  }
 	  (*x)[i*dim] = xx;
 	  (*x)[i*dim+1] = yy;
@@ -188,7 +189,7 @@ SparseMatrix SparseMatrix_import_dot(Agraph_t *g, int dim,
 	}
       } else {
         has_positions = false;
-	agerr(AGERR, "Node \"%s\" lacks position info", agnameof(n));
+	agerrorf("Node \"%s\" lacks position info", agnameof(n));
       }
     }
     if (!has_positions) {
@@ -197,7 +198,7 @@ SparseMatrix SparseMatrix_import_dot(Agraph_t *g, int dim,
     }
   }
   else if (x)
-    agerr (AGERR, "Error: graph %s has missing \"pos\" information", agnameof(g));
+    agerrorf("Error: graph %s has missing \"pos\" information", agnameof(g));
 
   size_t sz = sizeof(double);
   if (format == FORMAT_CSR) A = SparseMatrix_from_coordinate_arrays(nedges, nnodes, nnodes, I, J, val, type, sz);
@@ -446,7 +447,7 @@ SparseMatrix Import_coord_clusters_from_dot(Agraph_t* g, int maxcluster, int dim
       modularity_clustering(A, false, maxcluster,
 		    &nc, clusters, &modularity);
     } else {
-      assert(0);
+      UNREACHABLE();
     }
     for (i = 0; i < nnodes; i++) (*clusters)[i]++;/* make into 1 based */
     for (n = agfstnode (g); n; n = agnxtnode (g, n)) {
@@ -624,7 +625,7 @@ void attached_clustering(Agraph_t* g, int maxcluster, int clustering_scheme){
       modularity_clustering(A, false, maxcluster,
 			    &nc, &clusters, &modularity);
     } else {
-      assert(0);
+      UNREACHABLE();
     }
     for (i = 0; i < nnodes; i++) (clusters)[i]++;/* make into 1 based */
     for (n = agfstnode (g); n; n = agnxtnode (g, n)) {
