@@ -10,10 +10,6 @@
 
 #include "config.h"
 
-#ifdef _WIN32
-#include <io.h>
-#endif
-
 #include <stdarg.h>
 #include <stdbool.h>
 #include <stdlib.h>
@@ -33,6 +29,7 @@
 #include <common/utils.h>
 #include <gvc/gvc.h>
 #include <gvc/gvio.h>
+#include "core_loadimage_xdot.h"
 
 typedef enum {
 	FORMAT_DOT,
@@ -514,8 +511,7 @@ static void xdot_textspan(GVJ_t * job, pointf p, textspan_t * span)
     xdot_str (job, "", span->str);
 }
 
-static void xdot_color_stop (agxbuf* xb, float v, gvcolor_t* clr)
-{
+static void xdot_color_stop(agxbuf *xb, double v, gvcolor_t *clr) {
   agxbprint(xb, "%.03f", v);
   agxbuf_trim_zeros(xb);
   agxbputc(xb, ' ');
