@@ -11,14 +11,10 @@
 #include "config.h"
 #include <assert.h>
 #include <math.h>
-#include <stdarg.h>
+#include <stdbool.h>
 #include <stdlib.h>
 #include <string.h>
 
-#ifdef _WIN32
-#include <io.h>
-#endif
-
 #include <common/macros.h>
 #include <common/const.h>
 
@@ -40,23 +36,19 @@ typedef enum { FORMAT_FIG, } format_type;
 static int Depth;
 
 static void figptarray(GVJ_t *job, pointf *A, size_t n, int close) {
-    point p;
-
     for (size_t i = 0; i < n; i++) {
-	PF2P(A[i],p);
-        gvprintf(job, " %d %d", p.x, p.y);
+        gvprintf(job, " %.0f %.0f", A[i].x, A[i].y);
     }
     if (close) {
-	PF2P(A[0],p);
-        gvprintf(job, " %d %d", p.x, p.y);
+        gvprintf(job, " %.0f %.0f", A[0].x, A[0].y);
     }
     gvputs(job, "\n");
 }
 
-static int figColorResolve(int *new, unsigned char r, unsigned char g,
+static int figColorResolve(bool *new, unsigned char r, unsigned char g,
   unsigned char b)
 {
-#define maxColors 256
+#define maxColors 512
     static int top = 0;
     static short red[maxColors], green[maxColors], blue[maxColors];
     int c;
@@ -64,7 +56,7 @@ static int figColorResolve(int *new, unsigned char r, unsigned char g,
     long rd, gd, bd, dist;
     long mindist = 3 * 255 * 255;       /* init to max poss dist */
 
-    *new = 0;                   /* in case it is not a new color */
+    *new = false; // in case it is not a new color
     for (c = 0; c < top; c++) {
         rd = (long) (red[c] - r);
         gd = (long) (green[c] - g);
@@ -78,24 +70,24 @@ static int figColorResolve(int *new, unsigned char r, unsigned char g,
         }
     }
     /* no exact match.  We now know closest, but first try to allocate exact */
-    if (top++ == maxColors)
+    if (top == maxColors)
         return ct;              /* Return closest available color */
+    ++top;
     red[c] = r;
     green[c] = g;
     blue[c] = b;
-    *new = 1;                   /* flag new color */
+    *new = true; // flag new color
     return c;                   /* Return newly allocated color */
 }
 
 /* this table is in xfig color index order */
-static char *figcolor[] = {
-    "black", "blue", "green", "cyan", "red", "magenta", "yellow", "white", (char *) NULL
-};
+static char *figcolor[] = {"black",   "blue",   "green", "cyan", "red",
+                           "magenta", "yellow", "white", NULL};
 
 static void fig_resolve_color(GVJ_t *job, gvcolor_t * color)
 {
     int object_code = 0;        /* always 0 for color */
-    int i, new;
+    int i;
 
     switch (color->type) {
 	case COLOR_STRING:
@@ -106,7 +98,8 @@ static void fig_resolve_color(GVJ_t *job, gvcolor_t * color)
 		}
 	    }
 	    break;
-	case RGBA_BYTE:
+	case RGBA_BYTE: {
+	    bool new;
 	    i = 32 + figColorResolve(&new,
 			color->u.rgba[0],
 			color->u.rgba[1],
@@ -119,6 +112,7 @@ static void fig_resolve_color(GVJ_t *job, gvcolor_t * color)
 			color->u.rgba[2]);
 	    color->u.index = i;
 	    break;
+	}
 	default:
 	    UNREACHABLE(); // internal error
     }
@@ -317,7 +311,6 @@ static void fig_bezier(GVJ_t *job, pointf *A, size_t n, int filled) {
     int backward_arrow = 0;
 
     pointf pf, V[4];
-    point p;
     int step;
     int count = 0;
 
@@ -340,8 +333,7 @@ static void fig_bezier(GVJ_t *job, pointf *A, size_t n, int filled) {
     V[3].y = A[0].y;
     /* Write first point in line */
     count++;
-    PF2P(A[0], p);
-    agxbprint(&buf, " %d %d", p.x, p.y);
+    agxbprint(&buf, " %.0f %.0f", A[0].x, A[0].y);
     /* write subsequent points */
     for (size_t i = 0; i + 3 < n; i += 3) {
         V[0] = V[3];
@@ -352,8 +344,7 @@ static void fig_bezier(GVJ_t *job, pointf *A, size_t n, int filled) {
         for (step = 1; step <= BEZIERSUBDIVISION; step++) {
             count++;
             pf = Bezier(V, (double)step / BEZIERSUBDIVISION, NULL, NULL);
-	    PF2P(pf, p);
-            agxbprint(&buf, " %d %d", p.x, p.y);
+            agxbprint(&buf, " %.0f %.0f", pf.x, pf.y);
         }
     }
 
