@@ -9,6 +9,7 @@
  *************************************************************************/
 
 #include "tcldot.h"
+#include <cgraph/rdr.h>
 #include <stdlib.h>
 #include <string.h>
 
@@ -153,6 +154,7 @@ static int dotstring(ClientData clientData, Tcl_Interp *interp,
   return TCL_OK;
 }
 
+int Tcldot_Init(Tcl_Interp *interp);
 int Tcldot_Init(Tcl_Interp *interp) {
   ictx_t *ictx = calloc(1, sizeof(ictx_t));
   if (!ictx)
@@ -193,7 +195,7 @@ int Tcldot_Init(Tcl_Interp *interp) {
     return TCL_ERROR;
   }
 
-#if HAVE_LIBGD
+#ifdef HAVE_LIBGD
   Gdtclft_Init(interp);
 #endif
 
@@ -213,6 +215,8 @@ int Tcldot_Init(Tcl_Interp *interp) {
   return TCL_OK;
 }
 
+int Tcldot_SafeInit(Tcl_Interp *interp);
 int Tcldot_SafeInit(Tcl_Interp *interp) { return Tcldot_Init(interp); }
 
+int Tcldot_builtin_Init(Tcl_Interp *interp);
 int Tcldot_builtin_Init(Tcl_Interp *interp) { return Tcldot_Init(interp); }
