@@ -21,9 +21,6 @@
 /*    specifically just the change to Tcl_CmdProc */
 #define USE_NON_CONST
 
-/* for sincos */
-#define _GNU_SOURCE 1
-
 #include                <sys/types.h>
 #include                <stdbool.h>
 #include                <stdint.h>
@@ -41,6 +38,7 @@
 #include <pathplan/pathutil.h>
 #include <pathplan/vispath.h>
 #include <pathplan/tri.h>
+#include "Plegal_arrangement.h"
 #include <tcl.h>
 #include "tclhandle.h"
 
@@ -71,16 +69,8 @@ typedef struct vgpane_s {
     char *triangle_cmd;		/* why is this here any more */
 } vgpane_t;
 
-#ifdef HAVE_SINCOS
-extern void sincos(double x, double *s, double *c);
-#else
-# define sincos(x,s,c) *s = sin(x); *c = cos(x)
-#endif
-
 tblHeader_pt vgpaneTable;
 
-extern int Plegal_arrangement(Ppoly_t **polys, size_t n_polys);
-
 static int polyid = 0;		/* unique and unchanging id for each poly */
 
 static poly *allocpoly(vgpane_t * vgp, int id, int npts)
@@ -280,11 +270,12 @@ static double distance(point p, point q)
 static point rotate(point c, point p, double alpha)
 {
     point q;
-    double beta, r, sina, cosa;
+    double beta, r;
 
     r = distance(c, p);
     beta = atan2(p.x - c.x, p.y - c.y);
-    sincos(beta + alpha, &sina, &cosa);
+    const double sina = sin(beta + alpha);
+    const double cosa = cos(beta + alpha);
     q.x = c.x + r * sina;
     q.y = c.y - r * cosa;	/* adjust for tk y-down */
     return q;
@@ -392,7 +383,6 @@ vgpanecmd(ClientData clientData, Tcl_Interp * interp, int argc,
     double alpha, gain;
     Pvector_t slopes[2];
     Ppolyline_t line, spline;
-    int pp, qp;			/* polygon indices for p, q */
     Pedge_t *barriers;
 
     if (argc < 2) {
@@ -647,7 +637,8 @@ vgpanecmd(ClientData clientData, Tcl_Interp * interp, int argc,
 	    return result;
 
 	/* determine the polygons (if any) that contain the endpoints */
-	pp = qp = POLYID_NONE;
+	int pp = POLYID_NONE;
+	int qp = POLYID_NONE;
 	for (size_t i = 0; i < polys_size(&vgp->poly); i++) {
 	    poly *tpp = polys_at(&vgp->poly, i);
 	    if ((pp == POLYID_NONE) && in_poly(tpp->boundary, p))
@@ -786,6 +777,7 @@ vgpanecmd(ClientData clientData, Tcl_Interp * interp, int argc,
 	    if (polys_get(&vgp->poly, i).id == polyid) {
 		const size_t n = polys_get(&vgp->poly, i).boundary.pn;
 		ps = polys_get(&vgp->poly, i).boundary.ps;
+		p = center(ps, n);
 		for (size_t j = 0; j < n; j++) {
 		    appendpoint(interp, scale(p, ps[j], gain));
 		}
@@ -843,6 +835,7 @@ vgpane(ClientData clientData, Tcl_Interp * interp, int argc, char *argv[])
     return TCL_OK;
 }
 
+int Tclpathplan_Init(Tcl_Interp *interp);
 int Tclpathplan_Init(Tcl_Interp * interp)
 {
 #ifdef USE_TCL_STUBS
@@ -874,6 +867,7 @@ int Tclpathplan_Init(Tcl_Interp * interp)
     return TCL_OK;
 }
 
+int Tclpathplan_SafeInit(Tcl_Interp *interp);
 int Tclpathplan_SafeInit(Tcl_Interp * interp)
 {
     return Tclpathplan_Init(interp);
