@@ -95,6 +95,7 @@ def dot(
         "canon",
         "cmapx",
         "dot",
+        "fig",
         "json",
         "pic",
         "svg",
@@ -148,30 +149,11 @@ def gvpr(program: Path) -> str:
     )
 
 
-def is_centos() -> bool:
-    """
-    is the current environment CentOS?
-    """
-    return freedesktop_os_release().get("ID") == "centos"
-
-
 def is_cmake() -> bool:
     """was the Graphviz under test built with CMake?"""
     return os.getenv("build_system") == "cmake"
 
 
-def is_fedora() -> bool:
-    """is the current environment Fedora?"""
-    return freedesktop_os_release().get("ID") == "fedora"
-
-
-def is_fedora_38() -> bool:
-    """
-    is the current environment Fedora 38?
-    """
-    return is_fedora() and freedesktop_os_release().get("VERSION_ID") == "38"
-
-
 def is_macos() -> bool:
     """is the current platform macOS?"""
     return platform.system() == "Darwin"
@@ -182,6 +164,17 @@ def is_mingw() -> bool:
     return "mingw" in sysconfig.get_platform()
 
 
+def is_static_build() -> bool:
+    """was the build we are testing done with static linking?"""
+
+    if os.environ.get("BUILD_SHARED_LIBS") == "OFF":
+        return True
+
+    # answer “no” to other scenarios, even when some of them are statically
+    # linked, because the test suite is unaffected
+    return False
+
+
 def remove_xtype_warnings(s: str) -> str:
     """
     Remove macOS XType warnings from a string. These appear to be harmless, but
@@ -195,16 +188,25 @@ def remove_xtype_warnings(s: str) -> str:
     return re.sub(r"^.* XType: .*\.$\n", "", s, flags=re.MULTILINE)
 
 
+def is_rocky(wanted_version_id: Optional[str] = None) -> bool:
+    """
+    is the current environment Rocky Linux? And if specified, is it version `wanted_version_id`?
+    """
+    if freedesktop_os_release().get("ID") != "rocky":
+        return False
+    if wanted_version_id is None:
+        return True
+    version_id = freedesktop_os_release().get("VERSION_ID")
+    if version_id is None:
+        return False
+    return re.match(rf"{wanted_version_id}\b", version_id) is not None
+
+
 def is_rocky_8() -> bool:
     """
     is the current environment Rocky Linux 8?
     """
-    if freedesktop_os_release().get("ID") != "rocky":
-        return False
-    version_id = freedesktop_os_release().get("VERSION_ID")
-    if version_id is None:
-        return False
-    return re.match(r"8\b", version_id) is not None
+    return is_rocky("8")
 
 
 def run_c(
